@@ -32,9 +32,11 @@ from manila.api.v2 import availability_zones
 from manila.api.v2 import messages
 from manila.api.v2 import quota_class_sets
 from manila.api.v2 import quota_sets
+from manila.api.v2 import resource_locks
 from manila.api.v2 import services
 from manila.api.v2 import share_access_metadata
 from manila.api.v2 import share_accesses
+from manila.api.v2 import share_backups
 from manila.api.v2 import share_export_locations
 from manila.api.v2 import share_group_snapshots
 from manila.api.v2 import share_group_type_specs
@@ -51,6 +53,7 @@ from manila.api.v2 import share_snapshot_export_locations
 from manila.api.v2 import share_snapshot_instance_export_locations
 from manila.api.v2 import share_snapshot_instances
 from manila.api.v2 import share_snapshots
+from manila.api.v2 import share_transfer
 from manila.api.v2 import share_types
 from manila.api.v2 import shares
 from manila.api import versions
@@ -255,6 +258,44 @@ class APIRouter(manila.api.openstack.APIRouter):
                         controller=self.resources["snapshots"],
                         collection={"detail": "GET"},
                         member={"action": "POST"})
+        for path_prefix in ['/{project_id}', '']:
+            # project_id is optional
+            mapper.connect("snapshots_metadata",
+                           "%s/snapshots/{resource_id}/metadata"
+                           % path_prefix,
+                           controller=self.resources["snapshots"],
+                           action="create_metadata",
+                           conditions={"method": ["POST"]})
+            mapper.connect("snapshots_metadata",
+                           "%s/snapshots/{resource_id}/metadata"
+                           % path_prefix,
+                           controller=self.resources["snapshots"],
+                           action="update_all_metadata",
+                           conditions={"method": ["PUT"]})
+            mapper.connect("snapshots_metadata",
+                           "%s/snapshots/{resource_id}/metadata/{key}"
+                           % path_prefix,
+                           controller=self.resources["snapshots"],
+                           action="update_metadata_item",
+                           conditions={"method": ["POST"]})
+            mapper.connect("snapshots_metadata",
+                           "%s/snapshots/{resource_id}/metadata"
+                           % path_prefix,
+                           controller=self.resources["snapshots"],
+                           action="index_metadata",
+                           conditions={"method": ["GET"]})
+            mapper.connect("snapshots_metadata",
+                           "%s/snapshots/{resource_id}/metadata/{key}"
+                           % path_prefix,
+                           controller=self.resources["snapshots"],
+                           action="show_metadata",
+                           conditions={"method": ["GET"]})
+            mapper.connect("snapshots_metadata",
+                           "%s/snapshots/{resource_id}/metadata/{key}"
+                           % path_prefix,
+                           controller=self.resources["snapshots"],
+                           action="delete_metadata",
+                           conditions={"method": ["DELETE"]})
 
         for path_prefix in ['/{project_id}', '']:
             # project_id is optional
@@ -364,6 +405,48 @@ class APIRouter(manila.api.openstack.APIRouter):
                            action="index",
                            conditions={"method": ["GET"]})
 
+        for path_prefix in ['/{project_id}', '']:
+            # project_id is optional
+            mapper.connect("subnets_metadata",
+                           "%s/share-networks/{share_network_id}"
+                           "/subnets/{resource_id}/metadata" % path_prefix,
+                           controller=self.resources["share_network_subnets"],
+                           action="create_metadata",
+                           conditions={"method": ["POST"]})
+            mapper.connect("subnets_metadata",
+                           "%s/share-networks/{share_network_id}"
+                           "/subnets/{resource_id}/metadata" % path_prefix,
+                           controller=self.resources["share_network_subnets"],
+                           action="update_all_metadata",
+                           conditions={"method": ["PUT"]})
+            mapper.connect("subnets_metadata",
+                           "%s/share-networks/{share_network_id}"
+                           "/subnets/{resource_id}"
+                           "/metadata/{key}" % path_prefix,
+                           controller=self.resources["share_network_subnets"],
+                           action="update_metadata_item",
+                           conditions={"method": ["POST"]})
+            mapper.connect("subnets_metadata",
+                           "%s/share-networks/{share_network_id}"
+                           "/subnets/{resource_id}/metadata" % path_prefix,
+                           controller=self.resources["share_network_subnets"],
+                           action="index_metadata",
+                           conditions={"method": ["GET"]})
+            mapper.connect("subnets_metadata",
+                           "%s/share-networks/{share_network_id}"
+                           "/subnets/{resource_id}"
+                           "/metadata/{key}" % path_prefix,
+                           controller=self.resources["share_network_subnets"],
+                           action="show_metadata",
+                           conditions={"method": ["GET"]})
+            mapper.connect("subnets_metadata",
+                           "%s/share-networks/{share_network_id}"
+                           "/subnets/{resource_id}"
+                           "/metadata/{key}" % path_prefix,
+                           controller=self.resources["share_network_subnets"],
+                           action="delete_metadata",
+                           conditions={"method": ["DELETE"]})
+
         self.resources["share_servers"] = share_servers.create_resource()
         mapper.resource("share_server",
                         "share-servers",
@@ -506,6 +589,13 @@ class APIRouter(manila.api.openstack.APIRouter):
                         collection={'detail': 'GET'},
                         member={'action': 'POST'})
 
+        self.resources['share_transfers'] = (
+            share_transfer.create_resource())
+        mapper.resource("share-transfer", "share-transfers",
+                        controller=self.resources['share_transfers'],
+                        collection={'detail': 'GET'},
+                        member={'accept': 'POST'})
+
         self.resources["share-replica-export-locations"] = (
             share_replica_export_locations.create_resource())
         for path_prefix in ['/{project_id}', '']:
@@ -555,3 +645,14 @@ class APIRouter(manila.api.openstack.APIRouter):
                            controller=access_metadata_controller,
                            action="delete",
                            conditions={"method": ["DELETE"]})
+
+        self.resources['share-backups'] = share_backups.create_resource()
+        mapper.resource("share-backup",
+                        "share-backups",
+                        controller=self.resources['share-backups'],
+                        collection={'detail': 'GET'},
+                        member={'action': 'POST'})
+
+        self.resources["resource_locks"] = resource_locks.create_resource()
+        mapper.resource("resource-lock", "resource-locks",
+                        controller=self.resources["resource_locks"])
