@@ -17,10 +17,12 @@
 
 from http import client as http_client
 
+from oslo_utils import strutils
 import webob
 from webob import exc
 
 from manila.api import common
+from manila.api.openstack import api_version_request as api_version
 from manila.api.openstack import wsgi
 from manila.api.views import share_replicas as replication_view
 from manila.common import constants
@@ -174,11 +176,23 @@ class ShareReplicationController(wsgi.Controller, wsgi.AdminActionsMixin):
                     "since it has been soft deleted.") % share_id
             raise exc.HTTPForbidden(explanation=msg)
 
-        share_network_id = share_ref.get('share_network_id', None)
-
+        share_network_id = body.get('share_replica').get('share_network_id')
         if share_network_id:
-            share_network = db.share_network_get(context, share_network_id)
-            common.check_share_network_is_active(share_network)
+            if req.api_version_request < api_version.APIVersionRequest("2.72"):
+                msg = _("'share_network_id' option is not supported by this "
+                        "microversion. Use 2.72 or greater microversion to "
+                        "be able to use 'share_network_id'.")
+                raise exc.HTTPBadRequest(explanation=msg)
+        else:
+            share_network_id = share_ref.get('share_network_id', None)
+
+        try:
+            if share_network_id:
+                share_network = db.share_network_get(context, share_network_id)
+                common.check_share_network_is_active(share_network)
+        except exception.ShareNetworkNotFound:
+            msg = _("No share network exists with ID %s.")
+            raise exc.HTTPBadRequest(explanation=msg % share_network_id)
 
         try:
             new_replica = self.share_api.create_share_replica(
@@ -228,14 +242,21 @@ class ShareReplicationController(wsgi.Controller, wsgi.AdminActionsMixin):
     def promote(self, req, id, body):
         return self._promote(req, id, body)
 
-    @wsgi.Controller.api_version(GRADUATION_VERSION)  # noqa
+    @wsgi.Controller.api_version(GRADUATION_VERSION, "2.74")  # noqa
+    @wsgi.response(202)
+    @wsgi.action('promote')
+    def promote(self, req, id, body): # pylint: disable=function-redefined  # noqa F811
+        return self._promote(req, id, body)
+
+    @wsgi.Controller.api_version("2.75")  # noqa
     @wsgi.response(202)
     @wsgi.action('promote')
     def promote(self, req, id, body):  # pylint: disable=function-redefined  # noqa F811
-        return self._promote(req, id, body)
+        return self._promote(req, id, body, allow_quiesce_wait_time=True)
 
     @wsgi.Controller.authorize('promote')
-    def _promote(self, req, id, body):
+    def _promote(self, req, id, body,
+                 allow_quiesce_wait_time=False):
         """Promote a replica to active state."""
         context = req.environ['manila.context']
 
@@ -255,8 +276,25 @@ class ShareReplicationController(wsgi.Controller, wsgi.AdminActionsMixin):
         if replica_state == constants.REPLICA_STATE_ACTIVE:
             return webob.Response(status_int=http_client.OK)
 
+        quiesce_wait_time = None
+        if allow_quiesce_wait_time:
+            # NOTE(carloss): there is a chance that we receive
+            # {'promote': null}, so we need to prevent that
+            promote_data = body.get('promote', {})
+            promote_data = {} if promote_data is None else promote_data
+            wait_time = promote_data.get('quiesce_wait_time')
+            if wait_time:
+                if not strutils.is_int_like(wait_time) or int(wait_time) <= 0:
+                    msg = _("quiesce_wait_time must be an integer and "
+                            "greater than 0.")
+                    raise exc.HTTPBadRequest(explanation=msg)
+                else:
+                    quiesce_wait_time = int(wait_time)
+
         try:
-            replica = self.share_api.promote_share_replica(context, replica)
+            replica = self.share_api.promote_share_replica(
+                context, replica,
+                quiesce_wait_time=quiesce_wait_time)
         except exception.ReplicationException as e:
             raise exc.HTTPBadRequest(explanation=e.msg)
         except exception.AdminRequired as e:
