@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 
 # Copyright 2010 United States Government as represented by the
 # Administrator of the National Aeronautics and Space Administration.
@@ -20,14 +20,20 @@
 
 import eventlet
 eventlet.monkey_patch()
+# Monkey patch the original current_thread to use the up-to-date _active
+# global variable. See https://bugs.launchpad.net/bugs/1863021 and
+# https://github.com/eventlet/eventlet/issues/592
+import __original_module_threading as orig_threading
+import threading  # noqa
+orig_threading.current_thread.__globals__['_active'] = threading._active
 
 import sys
 
 from oslo_config import cfg
 from oslo_log import log
+from oslo_reports import guru_meditation_report as gmr
+from oslo_reports import opts as gmr_opts
 
-from manila import i18n
-i18n.enable_lazy()
 from manila.common import config  # Need to register global_opts  # noqa
 from manila import service
 from manila import utils
@@ -38,11 +44,14 @@ CONF = cfg.CONF
 
 def main():
     log.register_options(CONF)
+    gmr_opts.set_defaults(CONF)
     CONF(sys.argv[1:], project='manila',
          version=version.version_string())
     log.setup(CONF, "manila")
     utils.monkey_patch()
-    server = service.Service.create(binary='manila-scheduler')
+    gmr.TextGuruMeditation.setup_autorun(version, conf=CONF)
+    server = service.Service.create(binary='manila-scheduler',
+                                    coordination=True)
     service.serve(server)
     service.wait()
 
