@@ -322,6 +322,11 @@ def share_instance_delete(context, instance_id, session=None,
         need_to_update_usages=need_to_update_usages)
 
 
+def update_share_instance_quota_usages(context, instance_id, session=None):
+    """Update share instance quota usages"""
+    return IMPL.update_share_instance_quota_usages(context, instance_id)
+
+
 def share_instance_update(context, instance_id, values, with_share_data=False):
     """Update share instance fields."""
     return IMPL.share_instance_update(context, instance_id, values,
@@ -337,45 +342,47 @@ def share_and_snapshot_instances_status_update(
         current_expected_status=current_expected_status)
 
 
-def share_instances_status_update(context, share_instance_ids, values):
+def share_instance_status_update(context, share_instance_ids, values):
     """Updates the status of a bunch of share instances at once."""
-    return IMPL.share_instances_status_update(
+    return IMPL.share_instance_status_update(
         context, share_instance_ids, values)
 
 
-def share_instances_get_all(context, filters=None):
+def share_instance_get_all(context, filters=None):
     """Returns all share instances."""
-    return IMPL.share_instances_get_all(context, filters=filters)
+    return IMPL.share_instance_get_all(context, filters=filters)
 
 
-def share_instances_get_all_by_share_server(context, share_server_id,
-                                            with_share_data=False):
+def share_instance_get_all_by_share_server(
+    context, share_server_id, with_share_data=False,
+):
     """Returns all share instances with given share_server_id."""
-    return IMPL.share_instances_get_all_by_share_server(
+    return IMPL.share_instance_get_all_by_share_server(
         context, share_server_id, with_share_data=with_share_data)
 
 
-def share_instances_get_all_by_host(context, host, with_share_data=False,
-                                    status=None):
+def share_instance_get_all_by_host(
+    context, host, with_share_data=False, status=None,
+):
     """Returns all share instances with given host."""
-    return IMPL.share_instances_get_all_by_host(
+    return IMPL.share_instance_get_all_by_host(
         context, host, with_share_data=with_share_data, status=status)
 
 
-def share_instances_get_all_by_share_network(context, share_network_id):
+def share_instance_get_all_by_share_network(context, share_network_id):
     """Returns list of shares that belong to given share network."""
-    return IMPL.share_instances_get_all_by_share_network(context,
-                                                         share_network_id)
+    return IMPL.share_instance_get_all_by_share_network(
+        context, share_network_id)
 
 
-def share_instances_get_all_by_share(context, share_id):
+def share_instance_get_all_by_share(context, share_id):
     """Returns list of shares that belong to given share."""
-    return IMPL.share_instances_get_all_by_share(context, share_id)
+    return IMPL.share_instance_get_all_by_share(context, share_id)
 
 
-def share_instances_get_all_by_share_group_id(context, share_group_id):
+def share_instance_get_all_by_share_group_id(context, share_group_id):
     """Returns list of share instances that belong to given share group."""
-    return IMPL.share_instances_get_all_by_share_group_id(
+    return IMPL.share_instance_get_all_by_share_group_id(
         context, share_group_id)
 
 ###################
@@ -454,11 +461,10 @@ def share_get_all_by_share_server(context, share_server_id, filters=None,
         sort_dir=sort_dir)
 
 
-def get_shares_in_recycle_bin_by_share_server(
-        context, share_server_id, filters=None,
-        sort_key=None, sort_dir=None):
+def share_get_all_soft_deleted(
+        context, share_server_id, filters=None, sort_key=None, sort_dir=None):
     """Returns all shares in recycle bin with given share server ID."""
-    return IMPL.get_shares_in_recycle_bin_by_share_server(
+    return IMPL.share_get_all_soft_deleted(
         context, share_server_id, filters=filters, sort_key=sort_key,
         sort_dir=sort_dir)
 
@@ -471,11 +477,10 @@ def share_get_all_by_share_server_with_count(
         sort_dir=sort_dir)
 
 
-def get_shares_in_recycle_bin_by_network(
-        context, share_network_id, filters=None,
-        sort_key=None, sort_dir=None):
+def share_get_all_soft_deleted_by_network(
+        context, share_network_id, filters=None, sort_key=None, sort_dir=None):
     """Returns all shares in recycle bin with given share network ID."""
-    return IMPL.get_shares_in_recycle_bin_by_network(
+    return IMPL.share_get_all_soft_deleted_by_network(
         context, share_network_id, filters=filters, sort_key=sort_key,
         sort_dir=sort_dir)
 
@@ -497,9 +502,9 @@ def share_restore(context, share_id):
 ###################
 
 
-def share_transfer_get(context, transfer_id):
+def transfer_get(context, transfer_id):
     """Get a share transfer record or raise if it does not exist."""
-    return IMPL.share_transfer_get(context, transfer_id)
+    return IMPL.transfer_get(context, transfer_id)
 
 
 def transfer_get_all(context, limit=None, sort_key=None,
@@ -520,6 +525,11 @@ def transfer_get_all_by_project(context, project_id,
                                             filters=filters, offset=offset)
 
 
+def transfer_get_all_expired(context):
+    """Get all expired transfers DB records."""
+    return IMPL.transfer_get_all_expired(context)
+
+
 def transfer_create(context, values):
     """Create an entry in the transfers table."""
     return IMPL.transfer_create(context, values)
@@ -941,42 +951,46 @@ def share_metadata_update_item(context, share_id, item):
 
 ###################
 
-def share_export_location_get_by_uuid(context, export_location_uuid,
-                                      ignore_secondary_replicas=False):
+def export_location_get_by_uuid(
+    context, export_location_uuid, ignore_secondary_replicas=False,
+):
     """Get specific export location of a share."""
-    return IMPL.share_export_location_get_by_uuid(
+    return IMPL.export_location_get_by_uuid(
         context, export_location_uuid,
         ignore_secondary_replicas=ignore_secondary_replicas)
 
 
-def share_export_locations_get(context, share_id):
+def export_location_get_all(context, share_id):
     """Get all export locations of a share."""
-    return IMPL.share_export_locations_get(context, share_id)
+    return IMPL.export_location_get_all(context, share_id)
 
 
-def share_export_locations_get_by_share_id(context, share_id,
-                                           include_admin_only=True,
-                                           ignore_migration_destination=False,
-                                           ignore_secondary_replicas=False):
+def export_location_get_all_by_share_id(
+    context, share_id,
+    include_admin_only=True,
+    ignore_migration_destination=False,
+    ignore_secondary_replicas=False,
+):
     """Get all export locations of a share by its ID."""
-    return IMPL.share_export_locations_get_by_share_id(
+    return IMPL.export_location_get_all_by_share_id(
         context, share_id, include_admin_only=include_admin_only,
         ignore_migration_destination=ignore_migration_destination,
         ignore_secondary_replicas=ignore_secondary_replicas)
 
 
-def share_export_locations_get_by_share_instance_id(context,
-                                                    share_instance_id,
-                                                    include_admin_only=True):
+def export_location_get_all_by_share_instance_id(
+    context, share_instance_id, include_admin_only=True,
+):
     """Get all export locations of a share instance by its ID."""
-    return IMPL.share_export_locations_get_by_share_instance_id(
+    return IMPL.export_location_get_all_by_share_instance_id(
         context, share_instance_id, include_admin_only=include_admin_only)
 
 
-def share_export_locations_update(context, share_instance_id, export_locations,
-                                  delete=True):
+def export_locations_update(
+    context, share_instance_id, export_locations, delete=True,
+):
     """Update export locations of a share instance."""
-    return IMPL.share_export_locations_update(
+    return IMPL.export_locations_update(
         context, share_instance_id, export_locations, delete)
 
 
@@ -1292,14 +1306,9 @@ def share_server_get_all_unused_deletable(context, host, updated_before):
                                                       updated_before)
 
 
-def get_all_expired_shares(context):
+def share_get_all_expired(context):
     """Get all expired share DB records."""
-    return IMPL.get_all_expired_shares(context)
-
-
-def get_all_expired_transfers(context):
-    """Get all expired transfers DB records."""
-    return IMPL.get_all_expired_transfers(context)
+    return IMPL.share_get_all_expired(context)
 
 
 def share_server_backend_details_set(context, share_server_id, server_details):
