@@ -25,6 +25,7 @@ from sqlalchemy import Column, Integer, String, schema
 from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy import orm
 from sqlalchemy import ForeignKey, DateTime, Boolean, Enum
+from sqlalchemy_utils import generic_repr
 
 from manila.common import constants
 
@@ -32,6 +33,7 @@ CONF = cfg.CONF
 BASE = declarative_base()
 
 
+@generic_repr
 class ManilaBase(models.ModelBase,
                  models.TimestampMixin,
                  models.SoftDeleteMixin):
@@ -66,6 +68,7 @@ class Service(BASE, ManilaBase):
     state = Column(String(36))
     report_count = Column(Integer, nullable=False, default=0)
     disabled = Column(Boolean, default=False)
+    disabled_reason = Column(String(255))
     availability_zone_id = Column(String(36),
                                   ForeignKey('availability_zones.id'),
                                   nullable=True)
@@ -303,6 +306,7 @@ class Share(BASE, ManilaBase):
     display_name = Column(String(255))
     display_description = Column(String(255))
     snapshot_id = Column(String(36))
+    source_backup_id = Column(String(36))
     snapshot_support = Column(Boolean, default=True)
     create_share_from_snapshot_support = Column(Boolean, default=True)
     revert_to_snapshot_support = Column(Boolean, default=False)
@@ -367,7 +371,7 @@ class ShareInstance(BASE, ManilaBase):
     host = Column(String(255))
     status = Column(String(255))
     progress = Column(String(32))
-
+    mount_point_name = Column(String(255))
     ACCESS_STATUS_PRIORITIES = {
         constants.STATUS_ACTIVE: 0,
         constants.SHARE_INSTANCE_RULES_SYNCING: 1,
@@ -574,6 +578,15 @@ class ShareAccessMapping(BASE, ManilaBase):
             'ShareInstanceAccessMapping.deleted == "False")'
         )
     )
+    share = orm.relationship(
+        "Share",
+        primaryjoin=(
+            'and_('
+            'ShareAccessMapping.share_id == '
+            'Share.id, '
+            'Share.deleted == "False")'
+            )
+    )
 
 
 class ShareAccessRulesMetadata(BASE, ManilaBase):
@@ -1452,6 +1465,31 @@ class Message(BASE, ManilaBase):
     deleted = Column(String(36), default='False')
 
 
+class ResourceLock(BASE, ManilaBase):
+    """Represents a resource lock.
+
+    Resource locks are held by users (or on behalf of users) and prevent
+    actions to be performed on resources while the lock is present.
+    """
+    __tablename__ = 'resource_locks'
+    id = Column(String(36), primary_key=True, nullable=False)
+    user_id = Column(String(255), nullable=False)
+    project_id = Column(String(255), nullable=False)
+    # If the lock is held on behalf of the user, but created by 'service' or
+    # 'admin' users, as opposed to the user themselves ('project')
+    lock_context = Column(String(10), nullable=False)
+    # The uuid of the resource being locked.
+    resource_id = Column(String(36), nullable=False)
+    # The resource type, a constant dict will hold possible values
+    resource_type = Column(Enum(*constants.RESOURCE_LOCK_RESOURCE_TYPES),
+                           default=constants.SHARE_RESOURCE_TYPE)
+    # Action that lock prevents, a constant dict will hold possible values
+    resource_action = Column(Enum(*constants.RESOURCE_LOCK_RESOURCE_ACTIONS),
+                             default=constants.RESOURCE_ACTION_DELETE)
+    lock_reason = Column(String(1023), nullable=True)
+    deleted = Column(String(36), default='False')
+
+
 class BackendInfo(BASE, ManilaBase):
     """Represent Backend Info."""
     __tablename__ = "backend_info"
@@ -1467,6 +1505,51 @@ class AsynchronousOperationData(BASE, ManilaBase):
     value = Column(String(1023), nullable=False)
 
 
+class ShareBackup(BASE, ManilaBase):
+    """Represents a backup of a share."""
+    __tablename__ = 'share_backups'
+    id = Column(String(36), primary_key=True)
+
+    @property
+    def name(self):
+        return CONF.share_backup_name_template % self.id
+
+    @property
+    def availability_zone(self):
+        if self._availability_zone:
+            return self._availability_zone['name']
+
+    deleted = Column(String(36), default='False')
+    user_id = Column(String(255), nullable=False)
+    project_id = Column(String(255), nullable=False)
+
+    share_id = Column(String(36), ForeignKey('shares.id'))
+    size = Column(Integer)
+    host = Column(String(255))
+    topic = Column(String(255))
+    display_name = Column(String(255))
+    display_description = Column(String(255))
+    progress = Column(String(32))
+    restore_progress = Column(String(32))
+    status = Column(String(255))
+    fail_reason = Column(String(1023))
+    backup_type = Column(String(32))
+    availability_zone_id = Column(String(36),
+                                  ForeignKey('availability_zones.id'),
+                                  nullable=True)
+
+    _availability_zone = orm.relationship(
+        "AvailabilityZone",
+        lazy='immediate',
+        primaryjoin=(
+            'and_('
+            'ShareBackup.availability_zone_id == '
+            'AvailabilityZone.id, '
+            'AvailabilityZone.deleted == \'False\')'
+        )
+    )
+
+
 def register_models():
     """Register Models and create metadata.
 
