@@ -123,17 +123,14 @@ class NeutronNetworkPlugin(network.NetworkBaseAPI):
 
     def include_network_info(self, share_network_subnet):
         """Includes share-network-subnet with plugin specific data."""
-        self._store_and_get_neutron_net_info(None,
-                                             share_network_subnet,
-                                             save_db=False)
+        self._store_neutron_net_info(None, share_network_subnet, save_db=False)
 
-    def _store_and_get_neutron_net_info(self, context, share_network_subnet,
-                                        save_db=True):
-        is_external_network = self._save_neutron_network_data(
-            context, share_network_subnet, save_db=save_db)
+    def _store_neutron_net_info(self, context, share_network_subnet,
+                                save_db=True):
+        self._save_neutron_network_data(context, share_network_subnet,
+                                        save_db=save_db)
         self._save_neutron_subnet_data(context, share_network_subnet,
                                        save_db=save_db)
-        return is_external_network
 
     def allocate_network(self, context, share_server, share_network=None,
                          share_network_subnet=None, **kwargs):
@@ -159,23 +156,17 @@ class NeutronNetworkPlugin(network.NetworkBaseAPI):
         self._verify_share_network(share_server['id'], share_network)
         self._verify_share_network_subnet(share_server['id'],
                                           share_network_subnet)
-        is_external_network = self._store_and_get_neutron_net_info(
-            context, share_network_subnet)
+        self._store_neutron_net_info(context, share_network_subnet)
 
         allocation_count = kwargs.get('count', 1)
         device_owner = kwargs.get('device_owner', 'share')
 
         ports = []
         for current_count in range(0, allocation_count):
-            ports.append(
-                self._create_port(context,
-                                  share_server,
-                                  share_network,
-                                  share_network_subnet,
-                                  device_owner,
-                                  current_count,
-                                  is_external_network=is_external_network),
-            )
+            ports.append(self._create_port(
+                         context, share_server, share_network,
+                         share_network_subnet, device_owner,
+                         current_count))
 
         return ports
 
@@ -185,7 +176,7 @@ class NeutronNetworkPlugin(network.NetworkBaseAPI):
 
         self._verify_share_network_subnet(share_server['id'],
                                           share_network_subnet)
-        self._store_and_get_neutron_net_info(context, share_network_subnet)
+        self._store_neutron_net_info(context, share_network_subnet)
 
         # We begin matching the allocations to known neutron ports and
         # finally return the non-consumed allocations
@@ -305,8 +296,7 @@ class NeutronNetworkPlugin(network.NetworkBaseAPI):
                                                             ip_version}
         raise exception.NetworkBadConfigurationException(reason=msg)
 
-    def deallocate_network(self, context, share_server_id,
-                           share_network=None, share_network_subnet=None):
+    def deallocate_network(self, context, share_server_id):
         """Deallocate neutron network resources for the given share server.
 
         Delete previously allocated neutron ports, delete manila db
@@ -314,8 +304,6 @@ class NeutronNetworkPlugin(network.NetworkBaseAPI):
 
         :param context: RequestContext object
         :param share_server_id: id of share server
-        :param share_network: share network data
-        :param share_network_subnet: share network subnet data
         :rtype: None
         """
         ports = self.db.network_allocations_get_for_share_server(
@@ -324,56 +312,24 @@ class NeutronNetworkPlugin(network.NetworkBaseAPI):
         for port in ports:
             self._delete_port(context, port)
 
-        # It may be possible that there are ports existing without a
-        # corresponding manila network allocation entry in the manila db,
-        # because port create request may have been successfully sent to
-        # neutron, but the response, the created port could not be stored
-        # in manila due to unreachable db
-        if share_network_subnet:
-            ports = []
-            try:
-                ports = self.neutron_api.list_ports(
-                    network_id=share_network_subnet['neutron_net_id'],
-                    device_owner='manila:share',
-                    device_id=share_server_id)
-            except exception.NetworkException:
-                LOG.warning("Failed to list ports using neutron API during "
-                            "deallocate_network.")
-            for port in ports:
-                self._delete_port(context, port, ignore_db=True)
-
     def _get_port_create_args(self, share_server, share_network_subnet,
-                              device_owner, count=0,
-                              is_external_network=False):
+                              device_owner, count=0):
         return {
             "network_id": share_network_subnet['neutron_net_id'],
             "subnet_id": share_network_subnet['neutron_subnet_id'],
             "device_owner": 'manila:' + device_owner,
             "device_id": share_server.get('id'),
-            "name": share_server.get('id') + '_' + str(count),
-            # NOTE (gouthamr): we create disabled ports with external networks
-            # since the actual ports are not managed by neutron. The ports
-            # neutron creates merely assist in IPAM.
-            "admin_state_up": not is_external_network,
+            "name": share_server.get('id') + '_' + str(count)
         }
 
     def _create_port(self, context, share_server, share_network,
-                     share_network_subnet, device_owner, count=0,
-                     is_external_network=False):
+                     share_network_subnet, device_owner, count=0):
         create_args = self._get_port_create_args(
-            share_server, share_network_subnet, device_owner, count,
-            is_external_network=is_external_network)
+            share_server, share_network_subnet, device_owner, count)
 
         port = self.neutron_api.create_port(
             share_network['project_id'], **create_args)
 
-        if is_external_network:
-            msg = (
-                f"Port '{port['id']}' is disabled to prevent improper "
-                f"routing on an external network."
-            )
-            LOG.info(msg)
-
         ip_address = self._get_matched_ip_address(
             port['fixed_ips'], share_network_subnet['ip_version'])
         port_dict = {
@@ -398,7 +354,7 @@ class NeutronNetworkPlugin(network.NetworkBaseAPI):
 
         return self.db.network_allocation_create(context, port_dict)
 
-    def _delete_port(self, context, port, ignore_db=False):
+    def _delete_port(self, context, port):
         try:
             self.neutron_api.delete_port(port['id'])
         except exception.NetworkException:
@@ -406,8 +362,7 @@ class NeutronNetworkPlugin(network.NetworkBaseAPI):
                 context, port['id'], {'status': constants.STATUS_ERROR})
             raise
         else:
-            if not ignore_db:
-                self.db.network_allocation_delete(context, port['id'])
+            self.db.network_allocation_delete(context, port['id'])
 
     def _has_provider_network_extension(self):
         extensions = self.neutron_api.list_extensions()
@@ -425,7 +380,6 @@ class NeutronNetworkPlugin(network.NetworkBaseAPI):
             share_network_subnet['neutron_net_id'])
         segmentation_id = None
         network_type = None
-        is_external_network = net_info.get('router:external', False)
 
         if self._is_neutron_multi_segment(share_network_subnet, net_info):
             # we have a multi segment network and need to identify the
@@ -460,8 +414,6 @@ class NeutronNetworkPlugin(network.NetworkBaseAPI):
             self.db.share_network_subnet_update(
                 context, share_network_subnet['id'], provider_nw_dict)
 
-        return is_external_network
-
     def _save_neutron_subnet_data(self, context, share_network_subnet,
                                   save_db=True):
         subnet_info = self.neutron_api.get_subnet(
@@ -627,13 +579,10 @@ class NeutronBindNetworkPlugin(NeutronNetworkPlugin):
         raise exception.NetworkBindException(msg)
 
     def _get_port_create_args(self, share_server, share_network_subnet,
-                              device_owner, count=0,
-                              is_external_network=False):
+                              device_owner, count=0):
         arguments = super(
             NeutronBindNetworkPlugin, self)._get_port_create_args(
-            share_server, share_network_subnet, device_owner, count,
-            is_external_network=is_external_network
-        )
+            share_server, share_network_subnet, device_owner, count)
         arguments['host_id'] = self.config.neutron_host_id
         arguments['binding:vnic_type'] = self.config.neutron_vnic_type
         if self.binding_profiles:
