@@ -220,6 +220,13 @@ deprecated_update_admin_only_metadata = policy.DeprecatedRule(
     deprecated_since="YOGA"
 )
 
+deprecated_list_shares_in_deferred_deletion_states = policy.DeprecatedRule(
+    name=BASE_POLICY_NAME % 'list_shares_in_deferred_deletion_states',
+    check_str=base.RULE_ADMIN_API,
+    deprecated_reason=DEPRECATED_REASON,
+    deprecated_since='2024.1/Caracal'
+)
+
 shares_policies = [
     policy.DocumentedRuleDefault(
         name=BASE_POLICY_NAME % 'create',
@@ -658,6 +665,20 @@ shares_policies = [
         ],
         deprecated_rule=deprecated_share_get_metadata
     ),
+    policy.DocumentedRuleDefault(
+        name=BASE_POLICY_NAME % 'list_shares_in_deferred_deletion_states',
+        check_str=base.ADMIN,
+        scope_types=['project'],
+        description="List shares whose deletion has been deferred",
+        operations=[
+            {
+                'method': 'GET',
+                'path': '/v2/shares',
+            },
+        ],
+        deprecated_rule=deprecated_list_shares_in_deferred_deletion_states
+    ),
+
 ]
 
 # NOTE(gouthamr) For historic reasons, some snapshot policies used
