@@ -241,6 +241,18 @@ class FilterScheduler(base.Scheduler):
         # Note: remember, we are using an iterator here. So only
         # traverse this list once.
         hosts = self.host_manager.get_all_host_states_share(elevated)
+        if not hosts:
+            msg = _("There are no hosts to fulfill this "
+                    "provisioning request. Are share "
+                    "backend services down?")
+            self.message_api.create(
+                context,
+                message_field.Action.CREATE,
+                context.project_id,
+                resource_type=message_field.Resource.SHARE,
+                resource_id=request_spec.get('share_id', None),
+                detail=message_field.Detail.SHARE_BACKEND_NOT_READY_YET)
+            raise exception.WillNotSchedule(msg)
 
         # Filter local hosts based on requirements ...
         hosts, last_filter = self.host_manager.get_filtered_hosts(
@@ -360,6 +372,9 @@ class FilterScheduler(base.Scheduler):
         filter_properties['user_id'] = shr.get('user_id')
         filter_properties['metadata'] = shr.get('metadata')
         filter_properties['snapshot_id'] = shr.get('snapshot_id')
+        filter_properties['is_share_extend'] = (
+            request_spec.get('is_share_extend')
+        )
         self.populate_filter_properties_scheduler_hints(context, request_spec,
                                                         filter_properties)
 
@@ -528,8 +543,12 @@ class FilterScheduler(base.Scheduler):
             context, filter_properties, request_spec)
 
         hosts = self.host_manager.get_all_host_states_share(elevated)
+        filter_class_names = None
+        if request_spec.get('is_share_extend', None):
+            filter_class_names = CONF.scheduler_default_extend_filters
         hosts, last_filter = self.host_manager.get_filtered_hosts(
-            hosts, filter_properties)
+            hosts, filter_properties,
+            filter_class_names=filter_class_names)
         hosts = self.host_manager.get_weighed_hosts(hosts, filter_properties)
 
         for tgt_host in hosts:
