@@ -69,6 +69,14 @@ host_manager_opts = [
         ],
         help='Which filter class names to use for filtering hosts '
              'creating share group when not specified in the request.'),
+    cfg.ListOpt(
+        'scheduler_default_extend_filters',
+        default=[
+            'CapacityFilter',
+            'DriverFilter',
+        ],
+        help='Which filter class names to use for filtering hosts '
+             'extending share when not specified in the request.'),
 ]
 
 CONF = cfg.CONF
@@ -131,6 +139,7 @@ class HostState(object):
         self.free_capacity_gb = None
         self.reserved_percentage = 0
         self.reserved_snapshot_percentage = 0
+        self.reserved_share_extend_percentage = 0
         self.allocated_capacity_gb = 0
         # NOTE(xyang): The apparent allocated space indicating how much
         # capacity has been provisioned. This could be the sum of sizes
@@ -153,6 +162,7 @@ class HostState(object):
         self.security_service_update_support = False
         self.network_allocation_update_support = False
         self.share_server_multiple_subnet_support = False
+        self.mount_point_name_support = False
 
         # PoolState for all pools
         self.pools = {}
@@ -191,13 +201,14 @@ class HostState(object):
 
                 'pools':[
                   {
-                     'pool_name': '1st pool',           #\
-                     'total_capacity_gb': 500,          #  mandatory stats
-                     'free_capacity_gb': 230,           #   for pools
-                     'allocated_capacity_gb': 270,      # |
-                     'qos': 'False',                    # |
-                     'reserved_percentage': 0,          # |
-                     'reserved_snapshot_percentage': 0, #/
+                     'pool_name': '1st pool',               #\
+                     'total_capacity_gb': 500,              #  mandatory stats
+                     'free_capacity_gb': 230,               #   for pools
+                     'allocated_capacity_gb': 270,          # |
+                     'qos': 'False',                        # |
+                     'reserved_percentage': 0,              # |
+                     'reserved_snapshot_percentage': 0,     # |
+                     'reserved_share_extend_percentage': 0, #/
 
                      'dying_disks': 100,              #\
                      'super_hero_1': 'spider-man',    #  optional custom
@@ -213,6 +224,7 @@ class HostState(object):
                      'qos': 'False',
                      'reserved_percentage': 0,
                      'reserved_snapshot_percentage': 0,
+                     'reserved_share_extend_percentage': 0,
 
                      'dying_disks': 200,
                      'super_hero_1': 'superman',
@@ -431,7 +443,7 @@ class PoolState(HostState):
         """Estimate provisioned capacity from share sizes on backend."""
         provisioned_capacity = 0
 
-        instances = db.share_instances_get_all_by_host(
+        instances = db.share_instance_get_all_by_host(
             context, host_name, with_share_data=True)
 
         for instance in instances:
@@ -456,6 +468,8 @@ class PoolState(HostState):
             self.reserved_percentage = capability['reserved_percentage']
             self.reserved_snapshot_percentage = (
                 capability['reserved_snapshot_percentage'])
+            self.reserved_share_extend_percentage = (
+                capability['reserved_share_extend_percentage'])
             self.thin_provisioning = scheduler_utils.thin_provisioning(
                 capability.get('thin_provisioning', False))
             # NOTE(xyang): provisioned_capacity_gb is the apparent total
