@@ -38,6 +38,8 @@ def generate_stats(host_state, properties):
         'reserved_percentage': host_state.reserved_percentage,
         'reserved_snapshot_percentage':
             host_state.reserved_snapshot_percentage,
+        'reserved_share_extend_percentage':
+            host_state.reserved_share_extend_percentage,
         'driver_handles_share_servers':
             host_state.driver_handles_share_servers,
         'thin_provisioning': host_state.thin_provisioning,
@@ -64,7 +66,9 @@ def generate_stats(host_state, properties):
         'network_allocation_update_support': (
             host_state.network_allocation_update_support),
         'share_server_multiple_subnet_support': (
-            host_state.share_server_multiple_subnet_support)
+            host_state.share_server_multiple_subnet_support),
+        'mount_point_name_support': (
+            host_state.mount_point_name_support)
     }
 
     host_caps = host_state.capabilities
