@@ -21,6 +21,7 @@ from oslo_log import log
 
 from manila import exception
 from manila.i18n import _
+from manila import ssh_utils
 from manila import utils
 
 LOG = log.getLogger(__name__)
@@ -63,7 +64,7 @@ class SSHExecutor(object):
     """Callable encapsulating exec through ssh."""
 
     def __init__(self, *args, **kwargs):
-        self.pool = utils.SSHPool(*args, **kwargs)
+        self.pool = ssh_utils.SSHPool(*args, **kwargs)
 
     def __call__(self, *args, **kwargs):
         # argument with identifier 'run_as_root=' is not accepted by
@@ -105,7 +106,11 @@ def validate_access_rule(supported_access_types, supported_access_levels,
     errmsg = _("Unsupported access rule of 'type' %(access_type)s, "
                "'level' %(access_level)s, 'to' %(access_to)s: "
                "%(field)s should be one of %(supported)s.")
-    access_param = access_rule.to_dict()
+
+    if not isinstance(access_rule, dict):
+        access_param = access_rule.to_dict()
+    else:
+        access_param = access_rule
 
     def validate(field, supported_tokens, excinfo):
         if access_rule['access_%s' % field] in supported_tokens:
@@ -139,7 +144,7 @@ def validate_access_rule(supported_access_types, supported_access_levels,
 def fixup_access_rule(access_rule):
     """Adjust access rule as required for ganesha to handle it properly.
 
-    :param access_rule: Access rules to be validated.
+    :param access_rule: Access rules to be fixed up.
     :return: access_rule
     """
     if access_rule['access_to'] == '0.0.0.0/0':
