@@ -21,11 +21,12 @@ import xml.etree.cElementTree as etree
 
 from oslo_config import cfg
 from oslo_log import log
-import six
 
 from manila import exception
 from manila.i18n import _
+from manila.privsep import os as privsep_os
 from manila.share.drivers.ganesha import utils as ganesha_utils
+from manila import utils
 
 LOG = log.getLogger(__name__)
 
@@ -33,13 +34,11 @@ LOG = log.getLogger(__name__)
 glusterfs_common_opts = [
     cfg.StrOpt('glusterfs_server_password',
                secret=True,
-               deprecated_name='glusterfs_native_server_password',
                help='Remote GlusterFS server node\'s login password. '
                     'This is not required if '
                     '\'glusterfs_path_to_private_key\' is '
                     'configured.'),
     cfg.StrOpt('glusterfs_path_to_private_key',
-               deprecated_name='glusterfs_native_path_to_private_key',
                help='Path of Manila host\'s private SSH key file.'),
 ]
 
@@ -77,9 +76,9 @@ def volxml_get(xmlout, *paths, **kwargs):
 class GlusterManager(object):
     """Interface with a GlusterFS volume."""
 
-    scheme = re.compile('\A(?:(?P<user>[^:@/]+)@)?'
-                        '(?P<host>[^:@/]+)'
-                        '(?::/(?P<volume>[^/]+)(?P<path>/.*)?)?\Z')
+    scheme = re.compile(r'\A(?:(?P<user>[^:@/]+)@)?'
+                        r'(?P<host>[^:@/]+)'
+                        r'(?::/(?P<volume>[^/]+)(?P<path>/.*)?)?\Z')
 
     # See this about GlusterFS' convention for Boolean interpretation
     # of strings:
@@ -298,7 +297,7 @@ class GlusterManager(object):
 
     def get_vol_option(self, option, boolean=False):
         """Get the value of an option set on a GlusterFS volume."""
-        useropt = re.sub('\Auser\.', '', option)
+        useropt = re.sub(r'\Auser\.', '', option)
         if option == useropt:
             value = self._get_vol_regular_option(option)
         else:
@@ -315,6 +314,7 @@ class GlusterManager(object):
                 'volume': self.volume, 'option': option, 'value': value})
 
     @_check_volume_presence
+    @utils.retry(retry_param=exception.GlusterfsException)
     def set_vol_option(self, option, value, ignore_failure=False):
         value = {True: self.GLUSTERFS_TRUE_VALUES[0],
                  False: self.GLUSTERFS_FALSE_VALUES[0]}.get(value, value)
@@ -361,7 +361,7 @@ class GlusterManager(object):
                 "%(server)s, minimum requirement: %(minvers)s") % {
                 'server': self.host,
                 'version': '.'.join(vers),
-                'minvers': '.'.join(six.text_type(c) for c in minvers)})
+                'minvers': '.'.join(str(c) for c in minvers)})
 
 
 def numreduct(vers):
@@ -388,9 +388,8 @@ def _mount_gluster_vol(execute, gluster_export, mount_path, ensure=False):
     :param ensure: boolean to allow remounting a volume with a warning
     """
     execute('mkdir', '-p', mount_path)
-    command = ['mount', '-t', 'glusterfs', gluster_export, mount_path]
     try:
-        execute(*command, run_as_root=True)
+        privsep_os.mount(gluster_export, mount_path, mount_type='glusterfs')
     except exception.ProcessExecutionError as exc:
         if ensure and 'already mounted' in exc.stderr:
             LOG.warning("%s is already mounted.", gluster_export)
@@ -400,15 +399,14 @@ def _mount_gluster_vol(execute, gluster_export, mount_path, ensure=False):
             )
 
 
-def _umount_gluster_vol(execute, mount_path):
+def _umount_gluster_vol(mount_path):
     """Unmount a GlusterFS volume at the specified mount path.
 
-    :param execute: command execution function
     :param mount_path: path where volume is mounted
     """
 
     try:
-        execute('umount', mount_path, run_as_root=True)
+        privsep_os.umount(mount_path)
     except exception.ProcessExecutionError as exc:
         msg = (_("Unable to unmount gluster volume. "
                  "mount_dir: %(mount_path)s, Error: %(error)s") %
