@@ -24,7 +24,6 @@ import errno
 
 from oslo_config import cfg
 from oslo_utils import importutils
-import six
 
 from manila import exception
 from manila.i18n import _
@@ -82,7 +81,7 @@ class GlusterfsShareDriverBase(driver.ShareDriver):
                                                 False)
 
     def _setup_via_manager(self, share_mgr, share_mgr_parent=None):
-        """Callback for layout's `create_share` and `create_share_from_snapshot`
+        """Callback for layout's `create_share`/`create_share_from_snapshot`
 
         :param share_mgr: a {'share': <share>, 'manager': <gmgr>}
                dict where <share> is the share created
@@ -202,8 +201,7 @@ class GlusterfsShareDriverBase(driver.ShareDriver):
         super(GlusterfsShareDriverBase, self)._update_share_stats(data)
 
 
-@six.add_metaclass(abc.ABCMeta)
-class GlusterfsShareLayoutBase(object):
+class GlusterfsShareLayoutBase(metaclass=abc.ABCMeta):
     """Base class for share layouts."""
 
     def __init__(self, driver, *args, **kwargs):
@@ -235,7 +233,7 @@ class GlusterfsShareLayoutBase(object):
 
     @abc.abstractmethod
     def create_share_from_snapshot(self, context, share, snapshot,
-                                   share_server=None):
+                                   share_server=None, parent_share=None):
         """Is called to create share from snapshot."""
 
     @abc.abstractmethod
