@@ -613,6 +613,8 @@ class HitachiHNASDriver(driver.ShareDriver):
         reserved = self.configuration.safe_get('reserved_share_percentage')
         reserved_snapshot = self.configuration.safe_get(
             'reserved_share_from_snapshot_percentage') or reserved
+        reserved_share_extend = self.configuration.safe_get(
+            'reserved_share_extend_percentage') or reserved
 
         data = {
             'share_backend_name': self.backend_name,
@@ -624,6 +626,7 @@ class HitachiHNASDriver(driver.ShareDriver):
             'free_capacity_gb': free_space,
             'reserved_percentage': reserved,
             'reserved_snapshot_percentage': reserved_snapshot,
+            'reserved_share_extend_percentage': reserved_share_extend,
             'qos': False,
             'thin_provisioning': True,
             'dedupe': dedupe,
