@@ -119,7 +119,7 @@ class HuaweiNasDriver(driver.ShareDriver):
         self.plugin.extend_share(share, new_size, share_server)
 
     def create_share_from_snapshot(self, context, share, snapshot,
-                                   share_server=None):
+                                   share_server=None, parent_share=None):
         """Create a share from snapshot."""
         LOG.debug("Create a share from snapshot %s.", snapshot['snapshot_id'])
         location = self.plugin.create_share_from_snapshot(share, snapshot)
@@ -207,6 +207,7 @@ class HuaweiNasDriver(driver.ShareDriver):
             free_capacity_gb=0.0,
             snapshot_support=self.plugin.snapshot_support,
             create_share_from_snapshot_support=self.plugin.snapshot_support,
+            revert_to_snapshot_support=self.plugin.snapshot_support,
         )
 
         # huawei array doesn't support snapshot replication, so driver can't
@@ -222,6 +223,9 @@ class HuaweiNasDriver(driver.ShareDriver):
 
     def _setup_server(self, network_info, metadata=None):
         """Set up share server with given network parameters."""
+        # NOTE(felipe_rodrigues): keep legacy network_info support as a dict.
+        network_info = network_info[0]
+
         return self.plugin.setup_server(network_info, metadata)
 
     def _teardown_server(self, server_details, security_services=None):
@@ -250,7 +254,7 @@ class HuaweiNasDriver(driver.ShareDriver):
                                                 share_server)
 
     def promote_replica(self, context, replica_list, replica, access_rules,
-                        share_server=None):
+                        share_server=None, quiesce_wait_time=None):
         """Promote a replica to 'active' replica state.."""
         return self.plugin.promote_replica(context,
                                            replica_list,
@@ -266,3 +270,11 @@ class HuaweiNasDriver(driver.ShareDriver):
                                    replica_snapshots,
                                    replica,
                                    share_server)
+
+    def revert_to_snapshot(self, context, snapshot, share_access_rules,
+                           snapshot_access_rules, share_server=None):
+        self.plugin.revert_to_snapshot(context,
+                                       snapshot,
+                                       share_access_rules,
+                                       snapshot_access_rules,
+                                       share_server)
