@@ -210,6 +210,9 @@ class InfiniboxShareDriver(driver.ShareDriver):
             reserved_snapshot_percentage=(
                 self.configuration.reserved_share_from_snapshot_percentage
                 or self.configuration.reserved_share_percentage),
+            reserved_share_extend_percentage=(
+                self.configuration.reserved_share_extend_percentage
+                or self.configuration.reserved_share_percentage),
             thin_provisioning=self.configuration.infinidat_thin_provision,
             max_over_subscription_ratio=max_over_subscription_ratio,
             provisioned_capacity_gb=provisioned_capacity_gb,
