@@ -25,8 +25,9 @@ from lxml import etree
 from oslo_log import log
 from oslo_serialization import jsonutils
 import requests
+from requests.adapters import HTTPAdapter
 from requests import auth
-import six
+from requests.packages.urllib3.util.retry import Retry
 
 from manila import exception
 from manila.i18n import _
@@ -40,11 +41,13 @@ EVOLOPNOTSUPP = '160'
 EAPIERROR = '13001'
 EAPINOTFOUND = '13005'
 ESNAPSHOTNOTALLOWED = '13023'
+EVOLUMEDOESNOTEXIST = '13040'
 EVOLUMEOFFLINE = '13042'
 EINTERNALERROR = '13114'
 EINVALIDINPUTERROR = '13115'
 EDUPLICATEENTRY = '13130'
 EVOLNOTCLONE = '13170'
+EVOLOPNOTUNDERWAY = '13171'
 EVOLMOVE_CANNOT_MOVE_TO_CFO = '13633'
 EAGGRDOESNOTEXIST = '14420'
 EVOL_NOT_MOUNTED = '14716'
@@ -142,8 +145,8 @@ class BaseClient(object):
         try:
             self._api_major_version = int(major)
             self._api_minor_version = int(minor)
-            self._api_version = (six.text_type(major) + "." +
-                                 six.text_type(minor))
+            self._api_version = (str(major) + "." +
+                                 str(minor))
         except ValueError:
             raise ValueError('Major and minor versions must be integers')
         self._refresh_conn = True
@@ -171,7 +174,7 @@ class BaseClient(object):
             int(port)
         except ValueError:
             raise ValueError('Port must be integer')
-        self._port = six.text_type(port)
+        self._port = str(port)
         self._refresh_conn = True
 
     def get_port(self):
@@ -228,6 +231,11 @@ class BaseClient(object):
             auth_handler = self._create_certificate_auth_handler()
 
         self._session = requests.Session()
+
+        max_retries = Retry(total=5, connect=5, read=2, backoff_factor=1)
+        adapter = HTTPAdapter(max_retries=max_retries)
+        self._session.mount('%s://' % self._protocol, adapter)
+
         self._session.auth = auth_handler
         self._session.verify = self._ssl_verify
         headers = self._build_headers()
@@ -330,6 +338,8 @@ class ZapiClient(BaseClient):
             self._build_session()
         try:
             if hasattr(self, '_timeout'):
+                if self._timeout is None:
+                    self._timeout = 10
                 response = self._session.post(
                     self._get_url(), data=request_d, timeout=self._timeout)
             else:
@@ -338,7 +348,7 @@ class ZapiClient(BaseClient):
         except requests.HTTPError as e:
             raise NaApiError(e.errno, e.strerror)
         except requests.URLRequired as e:
-            raise exception.StorageCommunicationException(six.text_type(e))
+            raise exception.StorageCommunicationException(str(e))
         except Exception as e:
             raise NaApiError(message=e)
 
@@ -523,7 +533,7 @@ class RestClient(BaseClient):
         except requests.HTTPError as e:
             raise NaApiError(e.errno, e.strerror)
         except requests.URLRequired as e:
-            raise exception.StorageCommunicationException(six.text_type(e))
+            raise exception.StorageCommunicationException(str(e))
         except Exception as e:
             raise NaApiError(message=e)
 
@@ -851,8 +861,8 @@ class NaElement(object):
                     self.add_child_elem(child)
                 elif isinstance(
                         value,
-                        six.string_types + six.integer_types + (float, )):
-                    self.add_new_child(key, six.text_type(value))
+                        (str, ) + (int, ) + (float, )):
+                    self.add_new_child(key, str(value))
                 elif isinstance(value, (list, tuple, dict)):
                     child = NaElement(key)
                     child.translate_struct(value)
@@ -902,7 +912,7 @@ class NaElement(object):
                     child.translate_struct(data_struct[k])
                 else:
                     if data_struct[k]:
-                        child.set_content(six.text_type(data_struct[k]))
+                        child.set_content(str(data_struct[k]))
                 self.add_child_elem(child)
         else:
             raise ValueError(_('Type cannot be converted into NaElement.'))
@@ -993,7 +1003,7 @@ def create_api_request(api_name, query=None, des_result=None,
     if additional_elems:
         api_el.translate_struct(additional_elems)
     if is_iter:
-        api_el.add_new_child('max-records', six.text_type(record_step))
+        api_el.add_new_child('max-records', str(record_step))
     if tag:
         api_el.add_new_child('tag', tag, True)
     return api_el
