@@ -56,7 +56,8 @@ class NetAppBaseClient(object):
         if cached:
             return self.connection.get_system_version()
 
-        result = self.send_request('system-get-version')
+        result = self.send_request('system-get-version',
+                                   enable_tunneling=False)
 
         version_tuple = result.get_child_by_name(
             'version-tuple') or netapp_api.NaElement('none')
@@ -81,12 +82,13 @@ class NetAppBaseClient(object):
             return string.split('}', 1)[1]
         return string
 
-    def send_request(self, api_name, api_args=None, enable_tunneling=True):
+    def send_request(self, api_name, api_args=None, enable_tunneling=True,
+                     use_zapi=True):
         """Sends request to Ontapi."""
         request = netapp_api.NaElement(api_name)
-        if api_args:
-            request.translate_struct(api_args)
-        return self.connection.invoke_successfully(request, enable_tunneling)
+        return self.connection.invoke_successfully(
+            request, api_args=api_args, enable_tunneling=enable_tunneling,
+            use_zapi=use_zapi)
 
     @na_utils.trace
     def get_licenses(self):
@@ -97,8 +99,8 @@ class NetAppBaseClient(object):
                 LOG.exception("Could not get licenses list.")
 
         return sorted(
-            [l.get_child_content('package').lower()
-             for l in result.get_child_by_name('licenses').get_children()])
+            [child.get_child_content('package').lower()
+             for child in result.get_child_by_name('licenses').get_children()])
 
     def send_ems_log_message(self, message_dict):
         """Sends a message to the Data ONTAP EMS log."""
