@@ -380,3 +380,21 @@ class NetAppCmodeMultiSvmShareDriver(driver.ShareDriver):
         return self.library.update_share_server_network_allocations(
             context, share_server, current_network_allocations,
             new_network_allocations, security_services, shares, snapshots)
+
+    def create_backup(self, context, share, backup, **kwargs):
+        return self.library.create_backup(context, share, backup, **kwargs)
+
+    def create_backup_continue(self, context, share, backup, **kwargs):
+        return self.library.create_backup_continue(context, share, backup,
+                                                   **kwargs)
+
+    def restore_backup(self, context, backup, share, **kwargs):
+        return self.library.restore_backup(context, backup, share,
+                                           **kwargs)
+
+    def restore_backup_continue(self, context, backup, share, **kwargs):
+        return self.library.restore_backup_continue(context, backup, share,
+                                                    **kwargs)
+
+    def delete_backup(self, context, backup, share, **kwargs):
+        return self.library.delete_backup(context, backup, share, **kwargs)
