@@ -41,10 +41,13 @@ flashblade_connection_opts = [
         help="The name (or IP address) for the Pure Storage "
         "FlashBlade storage system management VIP.",
     ),
-    cfg.HostAddressOpt(
+    cfg.ListOpt(
         "flashblade_data_vip",
-        help="The name (or IP address) for the Pure Storage "
-        "FlashBlade storage system data VIP.",
+        help="The names (or IP address) for the Pure Storage "
+        "FlashBlade storage system data VIPs. "
+        "The first listed name or IP address will be considered "
+        "to be the preferred IP address, although is not "
+        "enforced.",
     ),
 ]
 
@@ -97,10 +100,11 @@ class FlashBladeShareDriver(driver.ShareDriver):
        4.0.0 - Zed release
        5.0.0 - Antelope release
        6.0.0 - Bobcat release
+       7.0.0 - 2024.1 (Caracal) release
 
     """
 
-    VERSION = "6.0"  # driver version
+    VERSION = "7.0"  # driver version
     USER_AGENT_BASE = "OpenStack Manila"
 
     def __init__(self, *args, **kwargs):
@@ -197,7 +201,19 @@ class FlashBladeShareDriver(driver.ShareDriver):
         super(FlashBladeShareDriver, self)._update_share_stats(data)
 
     def _get_available_capacity(self):
-        space = self._sys.arrays.list_arrays_space()
+        try:
+            space = self._sys.arrays.list_arrays_space()
+        except purity_fb.rest.ApiException:
+            message = "Connection failure. Retrying login..."
+            LOG.warning(message)
+            try:
+                self._sys.login(self.api)
+                self._sys._api_client.user_agent = self._user_agent
+            except purity_fb.rest.ApiException as ex:
+                msg = _("Exception when logging into the array: %s\n") % ex
+                LOG.exception(msg)
+                raise exception.ManilaException(message=msg)
+            space = self._sys.arrays.list_arrays_space()
         array_space = space.items[0]
         data_reduction = array_space.space.data_reduction
         physical_capacity_bytes = array_space.capacity
@@ -230,10 +246,9 @@ class FlashBladeShareDriver(driver.ShareDriver):
         base_name = CONF.share_name_template + "-manila"
         return base_name % manila_share["id"]
 
-    def _get_full_nfs_export_path(self, export_path):
-        subnet_ip = self.data_address
+    def _get_full_nfs_export_path(self, export_path, location):
         return "{subnet_ip}:/{export_path}".format(
-            subnet_ip=subnet_ip, export_path=export_path
+            subnet_ip=location, export_path=export_path
         )
 
     def _get_flashblade_filesystem_by_name(self, name):
@@ -258,18 +273,6 @@ class FlashBladeShareDriver(driver.ShareDriver):
             LOG.exception(msg)
             raise exception.ManilaException(message=msg)
 
-    @purity_fb_to_manila_exceptions
-    def _create_filesystem_export(self, flashblade_filesystem):
-        flashblade_export = flashblade_filesystem.add_export(permissions=[])
-        return {
-            "path": self._get_full_nfs_export_path(
-                flashblade_export.get_export_path()
-            ),
-            "is_admin_only": False,
-            "preferred": True,
-            "metadata": {},
-        }
-
     @purity_fb_to_manila_exceptions
     def _resize_share(self, share, new_size):
         dataset_name = self._make_share_name(share)
@@ -347,7 +350,22 @@ class FlashBladeShareDriver(driver.ShareDriver):
                 ),
             )
             self._sys.file_systems.create_file_systems(flashblade_fs)
-            location = self._get_full_nfs_export_path(share_name)
+            locations = []
+            preferred = True
+            for address in self.data_address:
+                export_location = {
+                    "path": self._get_full_nfs_export_path(
+                        share_name,
+                        address,
+                    ),
+                    "is_admin_only": False,
+                    "metadata": {
+                        "preferred": preferred,
+                    },
+                }
+                LOG.debug("pref %(pref)s", {"pref": preferred})
+                preferred = False
+                locations.append(export_location)
         else:
             message = _("Unsupported share protocol: %(proto)s.") % {
                 "proto": share["share_proto"]
@@ -356,7 +374,7 @@ class FlashBladeShareDriver(driver.ShareDriver):
             raise exception.InvalidShare(reason=message)
         LOG.info("FlashBlade created share %(name)s", {"name": share_name})
 
-        return location
+        return locations
 
     def create_snapshot(self, context, snapshot, share_server=None):
         """Called to create a snapshot"""
