@@ -21,11 +21,10 @@ Control Quobyte over its JSON RPC API.
 import requests
 from requests import auth
 from requests import codes
+from urllib import parse as urlparse
 
 from oslo_log import log
 from oslo_serialization import jsonutils
-import six
-import six.moves.urllib.parse as urlparse
 
 from manila import exception
 from manila import utils
@@ -59,7 +58,9 @@ class JsonRpc(object):
         self._cert_file = cert_file
 
     @utils.synchronized('quobyte-request')
-    def call(self, method_name, user_parameters, expected_errors=[]):
+    def call(self, method_name, user_parameters, expected_errors=None):
+        if expected_errors is None:
+            expected_errors = []
         # prepare request
         self._id += 1
         parameters = {'retry': 'INFINITELY'}  # Backend specific setting
@@ -69,7 +70,7 @@ class JsonRpc(object):
             'jsonrpc': '2.0',
             'method': method_name,
             'params': parameters,
-            'id': six.text_type(self._id),
+            'id': str(self._id),
         }
         LOG.debug("Request payload to be send is: %s",
                   jsonutils.dumps(post_data))
@@ -103,7 +104,9 @@ class JsonRpc(object):
         LOG.debug("Backend request resulted in error: %s", result.text)
         result.raise_for_status()
 
-    def _checked_for_application_error(self, result, expected_errors=[]):
+    def _checked_for_application_error(self, result, expected_errors=None):
+        if expected_errors is None:
+            expected_errors = []
         if 'error' in result and result['error']:
             if 'message' in result['error'] and 'code' in result['error']:
                 if result["error"]["code"] in expected_errors:
@@ -114,5 +117,5 @@ class JsonRpc(object):
                         result=result["error"]["message"],
                         qbcode=result["error"]["code"])
             else:
-                raise exception.QBException(six.text_type(result["error"]))
+                raise exception.QBException(str(result["error"]))
         return result["result"]
