@@ -361,6 +361,9 @@ class ZFSonLinuxShareDriver(zfs_utils.ExecuteMixin, driver.ShareDriver):
                 'reserved_snapshot_percentage': (
                     self.configuration.reserved_share_from_snapshot_percentage
                     or self.configuration.reserved_share_percentage),
+                'reserved_share_extend_percentage': (
+                    self.configuration.reserved_share_extend_percentage
+                    or self.configuration.reserved_share_percentage),
             }
             pool.update(self.common_capabilities)
             if self.configuration.replication_domain:
@@ -378,6 +381,9 @@ class ZFSonLinuxShareDriver(zfs_utils.ExecuteMixin, driver.ShareDriver):
             'reserved_snapshot_percentage': (
                 self.configuration.reserved_share_from_snapshot_percentage
                 or self.configuration.reserved_share_percentage),
+            'reserved_share_extend_percentage': (
+                self.configuration.reserved_share_extend_percentage
+                or self.configuration.reserved_share_percentage),
             'snapshot_support': True,
             'create_share_from_snapshot_support': True,
             'driver_name': 'ZFS',
@@ -1121,7 +1127,7 @@ class ZFSonLinuxShareDriver(zfs_utils.ExecuteMixin, driver.ShareDriver):
 
     @ensure_share_server_not_provided
     def promote_replica(self, context, replica_list, replica, access_rules,
-                        share_server=None):
+                        share_server=None, quiesce_wait_time=None):
         """Promotes secondary replica to active and active to secondary."""
         active_replica = self._get_active_replica(replica_list)
         src_dataset_name = self.private_storage.get(
