@@ -86,7 +86,11 @@ class HTTPRequest(os_wsgi.Request):
     @classmethod
     def blank(cls, *args, **kwargs):
         if not kwargs.get('base_url'):
-            kwargs['base_url'] = 'http://localhost/v1'
+            method_url = args[0]
+            if method_url.startswith('/v2'):
+                kwargs['base_url'] = 'http://localhost/share/v2'
+            else:
+                kwargs['base_url'] = 'http://localhost/share/v1'
         use_admin_context = kwargs.pop('use_admin_context', False)
         version = kwargs.pop('version', api_version.DEFAULT_API_VERSION)
         experimental = kwargs.pop('experimental', False)
@@ -202,11 +206,19 @@ fixture_reset_replica_status_with_different_roles = (
         'role': 'admin',
         'valid_code': 202,
         'valid_status': constants.STATUS_ERROR,
+        'microversion': '2.55'
+    },
+    {
+        'role': 'admin',
+        'valid_code': 202,
+        'valid_status': constants.STATUS_ERROR,
+        'microversion': '2.56'
     },
     {
         'role': 'member',
         'valid_code': 403,
         'valid_status': constants.STATUS_AVAILABLE,
+        'microversion': '2.55'
     },
 )
 
@@ -216,26 +228,31 @@ fixture_reset_replica_state_with_different_roles = (
         'role': 'admin',
         'valid_code': 202,
         'valid_status': constants.REPLICA_STATE_ACTIVE,
+        'microversion': '2.55'
     },
     {
         'role': 'admin',
         'valid_code': 202,
         'valid_status': constants.REPLICA_STATE_OUT_OF_SYNC,
+        'microversion': '2.56'
     },
     {
         'role': 'admin',
         'valid_code': 202,
         'valid_status': constants.REPLICA_STATE_IN_SYNC,
+        'microversion': '2.55'
     },
     {
         'role': 'admin',
         'valid_code': 202,
         'valid_status': constants.STATUS_ERROR,
+        'microversion': '2.56'
     },
     {
         'role': 'member',
         'valid_code': 403,
         'valid_status': constants.REPLICA_STATE_IN_SYNC,
+        'microversion': '2.55'
     },
 )
 
