@@ -12,8 +12,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from unittest import mock
+
 import ddt
-import mock
 
 from manila.api.v2 import availability_zones
 from manila import context
@@ -72,18 +73,18 @@ class AvailabilityZonesAPITest(test.TestCase):
 
         result = az_controller.index(req)
 
-        availability_zones.db.availability_zone_get_all.\
-            assert_called_once_with(ctxt)
+        (availability_zones.db.availability_zone_get_all.
+            assert_called_once_with(ctxt))
         mock_policy_check.assert_called_once_with(
             ctxt, controller.resource_name, 'index')
         self.assertIsInstance(result, dict)
         self.assertEqual(["availability_zones"], list(result.keys()))
         self.assertIsInstance(result["availability_zones"], list)
         self.assertEqual(2, len(result["availability_zones"]))
-        self.assertTrue(azs[0] in result["availability_zones"])
+        self.assertIn(azs[0], result["availability_zones"])
         azs[1].pop("deleted")
         azs[1].pop("redundant_key")
-        self.assertTrue(azs[1] in result["availability_zones"])
+        self.assertIn(azs[1], result["availability_zones"])
 
     @ddt.data(
         ('1.0', availability_zones.AvailabilityZoneController),
