@@ -252,7 +252,8 @@ class NeutronNetworkPluginTest(test.TestCase):
                 network_id=fake_share_network_subnet['neutron_net_id'],
                 subnet_id=fake_share_network_subnet['neutron_subnet_id'],
                 device_owner='manila:share',
-                device_id=fake_share_network['id'])
+                device_id=fake_share_network['id'],
+                name=fake_share_network['id'] + '_0')
             db_api.network_allocation_create.assert_called_once_with(
                 self.fake_context,
                 fake_network_allocation)
@@ -289,13 +290,15 @@ class NeutronNetworkPluginTest(test.TestCase):
                     network_id=fake_share_network_subnet['neutron_net_id'],
                     subnet_id=fake_share_network_subnet['neutron_subnet_id'],
                     device_owner='manila:share',
-                    device_id=fake_share_network['id']),
+                    device_id=fake_share_network['id'],
+                    name=fake_share_network['id'] + '_0'),
                 mock.call(
                     fake_share_network['project_id'],
                     network_id=fake_share_network_subnet['neutron_net_id'],
                     subnet_id=fake_share_network_subnet['neutron_subnet_id'],
                     device_owner='manila:share',
-                    device_id=fake_share_network['id']),
+                    device_id=fake_share_network['id'],
+                    name=fake_share_network['id'] + '_1'),
             ]
             db_api_calls = [
                 mock.call(self.fake_context, fake_network_allocation),
@@ -978,6 +981,7 @@ class NeutronBindNetworkPluginTest(test.TestCase):
                 'subnet_id': fake_share_network_subnet['neutron_subnet_id'],
                 'device_owner': 'manila:share',
                 'device_id': fake_share_network['id'],
+                'name': fake_share_network['id'] + '_0',
             }
             self.bind_plugin.neutron_api.create_port.assert_called_once_with(
                 fake_share_network['project_id'], **expected_kwargs)
@@ -1059,7 +1063,8 @@ class NeutronBindNetworkPluginTest(test.TestCase):
                 'network_id': fake_share_network_multi['neutron_net_id'],
                 'subnet_id': fake_share_network_multi['neutron_subnet_id'],
                 'device_owner': 'manila:share',
-                'device_id': fake_share_network_multi['id']
+                'device_id': fake_share_network_multi['id'],
+                'name': fake_share_network['id'] + '_0',
             }
             self.bind_plugin.neutron_api.create_port.assert_called_once_with(
                 fake_share_network_multi['project_id'], **expected_kwargs)
@@ -1174,7 +1179,8 @@ class NeutronBindNetworkPluginTest(test.TestCase):
             'network_id': fake_share_network_subnet['neutron_net_id'],
             'subnet_id': fake_share_network_subnet['neutron_subnet_id'],
             'device_owner': 'manila:' + fake_device_owner,
-            'device_id': fake_share_server['id']
+            'device_id': fake_share_server['id'],
+            'name': fake_share_server['id'] + '_0',
         }
         if neutron_binding_profiles:
             expected_create_args['binding:profile'] = {
@@ -1228,7 +1234,8 @@ class NeutronBindNetworkPluginTest(test.TestCase):
             'network_id': fake_share_network_subnet['neutron_net_id'],
             'subnet_id': fake_share_network_subnet['neutron_subnet_id'],
             'device_owner': 'manila:' + fake_device_owner,
-            'device_id': fake_share_server['id']
+            'device_id': fake_share_server['id'],
+            'name': fake_share_server['id'] + '_0'
         }
 
         self.assertEqual(expected_create_args, create_args)
@@ -1505,6 +1512,7 @@ class NeutronBindSingleNetworkPluginTest(test.TestCase):
                 'subnet_id': fake_share_network_subnet['neutron_subnet_id'],
                 'device_owner': 'manila:share',
                 'device_id': fake_share_network['id'],
+                'name': fake_share_network['id'] + '_0',
             }
             self.bind_plugin.neutron_api.create_port.assert_called_once_with(
                 fake_share_network['project_id'], **expected_kwargs)
@@ -1611,7 +1619,8 @@ class NeutronBindSingleNetworkPluginTest(test.TestCase):
             'network_id': fake_share_network_subnet['neutron_net_id'],
             'subnet_id': fake_share_network_subnet['neutron_subnet_id'],
             'device_owner': 'manila:' + fake_device_owner,
-            'device_id': fake_share_server['id']
+            'device_id': fake_share_server['id'],
+            'name': fake_share_server['id'] + '_0',
         }
         if neutron_binding_profiles:
             expected_create_args['binding:profile'] = {
@@ -1665,7 +1674,8 @@ class NeutronBindSingleNetworkPluginTest(test.TestCase):
             'network_id': fake_share_network_subnet['neutron_net_id'],
             'subnet_id': fake_share_network_subnet['neutron_subnet_id'],
             'device_owner': 'manila:' + fake_device_owner,
-            'device_id': fake_share_server['id']
+            'device_id': fake_share_server['id'],
+            'name': fake_share_server['id'] + '_0'
         }
 
         self.assertEqual(expected_create_args, create_args)
@@ -1734,6 +1744,7 @@ class NeutronBindNetworkPluginWithNormalTypeTest(test.TestCase):
                 'subnet_id': fake_share_network_subnet['neutron_subnet_id'],
                 'device_owner': 'manila:share',
                 'device_id': fake_share_server['id'],
+                'name': fake_share_server['id'] + '_0',
             }
             self.bind_plugin.neutron_api.create_port.assert_called_once_with(
                 fake_share_network['project_id'], **expected_kwargs)
@@ -1823,6 +1834,7 @@ class NeutronBindSingleNetworkPluginWithNormalTypeTest(test.TestCase):
                 'subnet_id': fake_share_network_subnet['neutron_subnet_id'],
                 'device_owner': 'manila:share',
                 'device_id': fake_share_network['id'],
+                'name': fake_share_network['id'] + '_0',
             }
             self.bind_plugin.neutron_api.create_port.assert_called_once_with(
                 fake_share_network['project_id'], **expected_kwargs)
