@@ -55,7 +55,8 @@ SERVICE_STATES_NO_POOLS = {
                   create_share_from_snapshot_support=False,
                   revert_to_snapshot_support=True,
                   mount_snapshot_support=True,
-                  driver_handles_share_servers=False),
+                  driver_handles_share_servers=False,
+                  mount_point_name_support=False),
     'host2@back1': dict(share_backend_name='BBB',
                         total_capacity_gb=256, free_capacity_gb=100,
                         timestamp=None, reserved_percentage=0,
@@ -68,7 +69,8 @@ SERVICE_STATES_NO_POOLS = {
                         create_share_from_snapshot_support=True,
                         revert_to_snapshot_support=False,
                         mount_snapshot_support=False,
-                        driver_handles_share_servers=False),
+                        driver_handles_share_servers=False,
+                        mount_point_name_support=False),
     'host2@back2': dict(share_backend_name='CCC',
                         total_capacity_gb=10000, free_capacity_gb=700,
                         timestamp=None, reserved_percentage=0,
@@ -81,7 +83,8 @@ SERVICE_STATES_NO_POOLS = {
                         create_share_from_snapshot_support=True,
                         revert_to_snapshot_support=False,
                         mount_snapshot_support=False,
-                        driver_handles_share_servers=False),
+                        driver_handles_share_servers=False,
+                        mount_point_name_support=False),
 }
 
 SHARE_SERVICES_WITH_POOLS = [
@@ -124,7 +127,9 @@ SHARE_SERVICE_STATES_WITH_POOLS = {
                                   reserved_share_extend_percentage=0,
                                   provisioned_capacity_gb=10,
                                   max_over_subscription_ratio=1.0,
-                                  thin_provisioning=False)]),
+                                  thin_provisioning=False,
+                                  mount_point_name_support=False,
+                                  )]),
     'host2@BBB': dict(share_backend_name='BBB',
                       timestamp=None, reserved_percentage=0,
                       reserved_snapshot_percentage=0,
@@ -142,7 +147,9 @@ SHARE_SERVICE_STATES_WITH_POOLS = {
                                   reserved_share_extend_percentage=0,
                                   provisioned_capacity_gb=60,
                                   max_over_subscription_ratio=2.0,
-                                  thin_provisioning=True)]),
+                                  thin_provisioning=True,
+                                  mount_point_name_support=False,
+                                  )]),
     'host3@CCC': dict(share_backend_name='CCC',
                       timestamp=None, reserved_percentage=0,
                       reserved_snapshot_percentage=0,
@@ -160,7 +167,9 @@ SHARE_SERVICE_STATES_WITH_POOLS = {
                                   reserved_share_extend_percentage=0,
                                   provisioned_capacity_gb=100,
                                   max_over_subscription_ratio=20.0,
-                                  thin_provisioning=True)]),
+                                  thin_provisioning=True,
+                                  mount_point_name_support=False,
+                                  )]),
     'host4@DDD': dict(share_backend_name='DDD',
                       timestamp=None, reserved_percentage=0,
                       reserved_snapshot_percentage=0,
@@ -178,7 +187,9 @@ SHARE_SERVICE_STATES_WITH_POOLS = {
                                   reserved_share_extend_percentage=0,
                                   provisioned_capacity_gb=800,
                                   max_over_subscription_ratio=2.0,
-                                  thin_provisioning=True),
+                                  thin_provisioning=True,
+                                  mount_point_name_support=False,
+                                  ),
                              dict(pool_name='pool4b',
                                   total_capacity_gb=542,
                                   free_capacity_gb=442,
@@ -187,7 +198,9 @@ SHARE_SERVICE_STATES_WITH_POOLS = {
                                   reserved_share_extend_percentage=0,
                                   provisioned_capacity_gb=2000,
                                   max_over_subscription_ratio=10.0,
-                                  thin_provisioning=True)]),
+                                  thin_provisioning=True,
+                                  mount_point_name_support=False,
+                                  )]),
     'host5@EEE': dict(share_backend_name='EEE',
                       timestamp=None, reserved_percentage=0,
                       reserved_snapshot_percentage=0,
@@ -205,7 +218,9 @@ SHARE_SERVICE_STATES_WITH_POOLS = {
                                   reserved_share_extend_percentage=0,
                                   provisioned_capacity_gb=100,
                                   max_over_subscription_ratio=1.0,
-                                  thin_provisioning=False),
+                                  thin_provisioning=False,
+                                  mount_point_name_support=False,
+                                  ),
                              dict(pool_name='pool5b',
                                   total_capacity_gb=552,
                                   free_capacity_gb=452,
@@ -214,7 +229,9 @@ SHARE_SERVICE_STATES_WITH_POOLS = {
                                   reserved_share_extend_percentage=0,
                                   provisioned_capacity_gb=100,
                                   max_over_subscription_ratio=1.0,
-                                  thin_provisioning=False)]),
+                                  thin_provisioning=False,
+                                  mount_point_name_support=False,
+                                  )]),
     'host6@FFF': dict(share_backend_name='FFF',
                       timestamp=None, reserved_percentage=0,
                       reserved_snapshot_percentage=0,
@@ -232,7 +249,9 @@ SHARE_SERVICE_STATES_WITH_POOLS = {
                                   reserved_share_extend_percentage=0,
                                   provisioned_capacity_gb=100,
                                   max_over_subscription_ratio=1.0,
-                                  thin_provisioning=False),
+                                  thin_provisioning=False,
+                                  mount_point_name_support=False,
+                                  ),
                              dict(pool_name='pool6b',
                                   total_capacity_gb='unknown',
                                   free_capacity_gb='unknown',
@@ -241,7 +260,9 @@ SHARE_SERVICE_STATES_WITH_POOLS = {
                                   reserved_share_extend_percentage=0,
                                   provisioned_capacity_gb=100,
                                   max_over_subscription_ratio=1.0,
-                                  thin_provisioning=False)]),
+                                  thin_provisioning=False,
+                                  mount_point_name_support=False,
+                                  )]),
 }
 
 FAKE_ACTIVE_IQ_WEIGHER_LIST = [
