@@ -18,7 +18,6 @@ Tests For CapabilitiesFilter.
 """
 
 import ddt
-from oslo_context import context
 
 from manila.scheduler.filters import capabilities
 from manila import test
@@ -31,7 +30,6 @@ class HostFiltersTestCase(test.TestCase):
 
     def setUp(self):
         super(HostFiltersTestCase, self).setUp()
-        self.context = context.RequestContext('fake', 'fake')
         self.filter = capabilities.CapabilitiesFilter()
 
     def _do_test_type_filter_extra_specs(self, ecaps, especs, passes):
@@ -47,12 +45,38 @@ class HostFiltersTestCase(test.TestCase):
         assertion = self.assertTrue if passes else self.assertFalse
         assertion(self.filter.host_passes(host, filter_properties))
 
+    def test_mount_point_name_support_pass(self):
+        capabilities = {'mount_point_name_support': True}
+        service = {'disabled': False}
+        filter_properties = {
+            'resource_type': {
+                'request_spec': {
+                    'share_properties': {
+                        'mount_point_name': 'fake_mp',
+                    }
+                }
+            }
+        }
+        host = fakes.FakeHostState('host1',
+                                   {'free_capacity_gb': 1024,
+                                    'capabilities': capabilities,
+                                    'service': service})
+        self.assertTrue(self.filter.host_passes(host, filter_properties))
+
     def test_capability_filter_passes_extra_specs_simple(self):
         self._do_test_type_filter_extra_specs(
             ecaps={'opt1': '1', 'opt2': '2'},
             especs={'opt1': '1', 'opt2': '2'},
             passes=True)
 
+    def test_capability_filter_passes_extra_specs_ignore_azs_spec(self):
+        self._do_test_type_filter_extra_specs(
+            ecaps={'opt1': '1', 'opt2': '2'},
+            especs={'opt1': '1',
+                    'opt2': '2',
+                    'availability_zones': 'az1,az2'},
+            passes=True)
+
     def test_capability_filter_fails_extra_specs_simple(self):
         self._do_test_type_filter_extra_specs(
             ecaps={'opt1': '1', 'opt2': '2'},
