@@ -198,6 +198,7 @@ class HostManagerTestCase(test.TestCase):
                         'total_capacity_gb': 512,
                         'reserved_percentage': 0,
                         'reserved_snapshot_percentage': 0,
+                        'reserved_share_extend_percentage': 0,
                         'provisioned_capacity_gb': 312,
                         'max_over_subscription_ratio': 1.0,
                         'thin_provisioning': False,
@@ -216,6 +217,7 @@ class HostManagerTestCase(test.TestCase):
                         'security_service_update_support': False,
                         'network_allocation_update_support': False,
                         'share_server_multiple_subnet_support': False,
+                        'mount_point_name_support': False,
                     },
                 }, {
                     'name': 'host2@back1#BBB',
@@ -230,6 +232,7 @@ class HostManagerTestCase(test.TestCase):
                         'total_capacity_gb': 256,
                         'reserved_percentage': 0,
                         'reserved_snapshot_percentage': 0,
+                        'reserved_share_extend_percentage': 0,
                         'provisioned_capacity_gb': 400,
                         'max_over_subscription_ratio': 2.0,
                         'thin_provisioning': True,
@@ -248,6 +251,7 @@ class HostManagerTestCase(test.TestCase):
                         'security_service_update_support': False,
                         'network_allocation_update_support': False,
                         'share_server_multiple_subnet_support': False,
+                        'mount_point_name_support': False,
                     },
                 }, {
                     'name': 'host2@back2#CCC',
@@ -262,6 +266,7 @@ class HostManagerTestCase(test.TestCase):
                         'total_capacity_gb': 10000,
                         'reserved_percentage': 0,
                         'reserved_snapshot_percentage': 0,
+                        'reserved_share_extend_percentage': 0,
                         'provisioned_capacity_gb': 50000,
                         'max_over_subscription_ratio': 20.0,
                         'thin_provisioning': True,
@@ -280,6 +285,7 @@ class HostManagerTestCase(test.TestCase):
                         'security_service_update_support': False,
                         'network_allocation_update_support': False,
                         'share_server_multiple_subnet_support': False,
+                        'mount_point_name_support': False,
                     },
                 },
             ]
@@ -316,6 +322,7 @@ class HostManagerTestCase(test.TestCase):
                         'total_capacity_gb': 51,
                         'reserved_percentage': 0,
                         'reserved_snapshot_percentage': 0,
+                        'reserved_share_extend_percentage': 0,
                         'provisioned_capacity_gb': 10,
                         'max_over_subscription_ratio': 1.0,
                         'thin_provisioning': False,
@@ -334,6 +341,7 @@ class HostManagerTestCase(test.TestCase):
                         'security_service_update_support': False,
                         'network_allocation_update_support': False,
                         'share_server_multiple_subnet_support': False,
+                        'mount_point_name_support': False,
                     },
                 }, {
                     'name': 'host2@BBB#pool2',
@@ -349,6 +357,7 @@ class HostManagerTestCase(test.TestCase):
                         'total_capacity_gb': 52,
                         'reserved_percentage': 0,
                         'reserved_snapshot_percentage': 0,
+                        'reserved_share_extend_percentage': 0,
                         'provisioned_capacity_gb': 60,
                         'max_over_subscription_ratio': 2.0,
                         'thin_provisioning': True,
@@ -367,6 +376,7 @@ class HostManagerTestCase(test.TestCase):
                         'security_service_update_support': False,
                         'network_allocation_update_support': False,
                         'share_server_multiple_subnet_support': False,
+                        'mount_point_name_support': False,
                     },
                 }, {
                     'name': 'host3@CCC#pool3',
@@ -382,6 +392,7 @@ class HostManagerTestCase(test.TestCase):
                         'total_capacity_gb': 53,
                         'reserved_percentage': 0,
                         'reserved_snapshot_percentage': 0,
+                        'reserved_share_extend_percentage': 0,
                         'provisioned_capacity_gb': 100,
                         'max_over_subscription_ratio': 20.0,
                         'thin_provisioning': True,
@@ -400,6 +411,7 @@ class HostManagerTestCase(test.TestCase):
                         'security_service_update_support': False,
                         'network_allocation_update_support': False,
                         'share_server_multiple_subnet_support': False,
+                        'mount_point_name_support': False,
                     },
                 }, {
                     'name': 'host4@DDD#pool4a',
@@ -415,6 +427,7 @@ class HostManagerTestCase(test.TestCase):
                         'total_capacity_gb': 541,
                         'reserved_percentage': 0,
                         'reserved_snapshot_percentage': 0,
+                        'reserved_share_extend_percentage': 0,
                         'provisioned_capacity_gb': 800,
                         'max_over_subscription_ratio': 2.0,
                         'thin_provisioning': True,
@@ -433,6 +446,7 @@ class HostManagerTestCase(test.TestCase):
                         'security_service_update_support': False,
                         'network_allocation_update_support': False,
                         'share_server_multiple_subnet_support': False,
+                        'mount_point_name_support': False,
                     },
                 }, {
                     'name': 'host4@DDD#pool4b',
@@ -448,6 +462,7 @@ class HostManagerTestCase(test.TestCase):
                         'total_capacity_gb': 542,
                         'reserved_percentage': 0,
                         'reserved_snapshot_percentage': 0,
+                        'reserved_share_extend_percentage': 0,
                         'provisioned_capacity_gb': 2000,
                         'max_over_subscription_ratio': 10.0,
                         'thin_provisioning': True,
@@ -466,6 +481,7 @@ class HostManagerTestCase(test.TestCase):
                         'security_service_update_support': False,
                         'network_allocation_update_support': False,
                         'share_server_multiple_subnet_support': False,
+                        'mount_point_name_support': False,
                     },
                 },
             ]
@@ -519,6 +535,7 @@ class HostManagerTestCase(test.TestCase):
                         'total_capacity_gb': 512,
                         'reserved_percentage': 0,
                         'reserved_snapshot_percentage': 0,
+                        'reserved_share_extend_percentage': 0,
                         'vendor_name': None,
                         'storage_protocol': None,
                         'provisioned_capacity_gb': 312,
@@ -532,6 +549,7 @@ class HostManagerTestCase(test.TestCase):
                         'security_service_update_support': False,
                         'network_allocation_update_support': False,
                         'share_server_multiple_subnet_support': False,
+                        'mount_point_name_support': False,
                     },
                 }, {
                     'name': 'host2@back1#BBB',
@@ -551,6 +569,7 @@ class HostManagerTestCase(test.TestCase):
                         'total_capacity_gb': 256,
                         'reserved_percentage': 0,
                         'reserved_snapshot_percentage': 0,
+                        'reserved_share_extend_percentage': 0,
                         'vendor_name': None,
                         'storage_protocol': None,
                         'provisioned_capacity_gb': 400,
@@ -564,6 +583,7 @@ class HostManagerTestCase(test.TestCase):
                         'security_service_update_support': False,
                         'network_allocation_update_support': False,
                         'share_server_multiple_subnet_support': False,
+                        'mount_point_name_support': False,
                     },
                 },
             ]
@@ -611,6 +631,7 @@ class HostManagerTestCase(test.TestCase):
                         'total_capacity_gb': 52,
                         'reserved_percentage': 0,
                         'reserved_snapshot_percentage': 0,
+                        'reserved_share_extend_percentage': 0,
                         'provisioned_capacity_gb': 60,
                         'max_over_subscription_ratio': 2.0,
                         'thin_provisioning': True,
@@ -624,10 +645,11 @@ class HostManagerTestCase(test.TestCase):
                         'security_service_update_support': False,
                         'network_allocation_update_support': False,
                         'share_server_multiple_subnet_support': False,
+                        'mount_point_name_support': False,
                     },
                 },
             ]
-            self.assertTrue(isinstance(res, list))
+            self.assertIsInstance(res, list)
             self.assertEqual(len(expected), len(res))
             for pool in expected:
                 self.assertIn(pool, res)
@@ -678,6 +700,7 @@ class HostStateTestCase(test.TestCase):
                             'free_capacity_gb': 100,
                             'reserved_percentage': 0,
                             'reserved_snapshot_percentage': 0,
+                            'reserved_share_extend_percentage': 0,
                             'timestamp': None,
                             'ipv4_support': True,
                             'ipv6_support': False}
@@ -731,6 +754,7 @@ class HostStateTestCase(test.TestCase):
                  'qos': 'False',
                  'reserved_percentage': 0,
                  'reserved_snapshot_percentage': 0,
+                 'reserved_share_extend_percentage': 0,
                  'dying_disks': 100,
                  'super_hero_1': 'spider-man',
                  'super_hero_2': 'flash',
@@ -743,6 +767,7 @@ class HostStateTestCase(test.TestCase):
                  'qos': 'False',
                  'reserved_percentage': 0,
                  'reserved_snapshot_percentage': 0,
+                 'reserved_share_extend_percentage': 0,
                  'dying_disks': 200,
                  'super_hero_1': 'superman',
                  'super_hero_2': 'Hulk',
@@ -789,6 +814,7 @@ class HostStateTestCase(test.TestCase):
                  'qos': 'False',
                  'reserved_percentage': 0,
                  'reserved_snapshot_percentage': 0,
+                 'reserved_share_extend_percentage': 0,
                  },
             ],
             'timestamp': None,
@@ -816,6 +842,7 @@ class HostStateTestCase(test.TestCase):
             'allocated_capacity_gb': 1,
             'reserved_percentage': 0,
             'reserved_snapshot_percentage': 0,
+            'reserved_share_extend_percentage': 0,
             'timestamp': None
         }
         fake_context = context.RequestContext('user', 'project', is_admin=True)
@@ -845,6 +872,7 @@ class HostStateTestCase(test.TestCase):
             'allocated_capacity_gb': provisioned_capacity_gb,
             'reserved_percentage': 0,
             'reserved_snapshot_percentage': 0,
+            'reserved_share_extend_percentage': 0,
             'timestamp': None
         }
         fake_host = host_manager.PoolState('host1', share_capability, '_pool0')
@@ -867,6 +895,7 @@ class HostStateTestCase(test.TestCase):
             'allocated_capacity_gb': 0,
             'reserved_percentage': 0,
             'reserved_snapshot_percentage': 0,
+            'reserved_share_extend_percentage': 0,
             'timestamp': None
         }
         fake_context = context.RequestContext('user', 'project', is_admin=True)
@@ -905,6 +934,7 @@ class HostStateTestCase(test.TestCase):
             'timestamp': None,
             'reserved_percentage': 0,
             'reserved_snapshot_percentage': 0,
+            'reserved_share_extend_percentage': 0,
         }
         fake_context = context.RequestContext('user', 'project', is_admin=True)
         fake_host = host_manager.HostState('host1')
@@ -928,6 +958,7 @@ class PoolStateTestCase(test.TestCase):
                 {'total_capacity_gb': 1024, 'free_capacity_gb': 512,
                  'reserved_percentage': 0, 'timestamp': None,
                  'reserved_snapshot_percentage': 0,
+                 'reserved_share_extend_percentage': 0,
                  'thin_provisioning': True,
                  'cap1': 'val1', 'cap2': 'val2'},
             'instances':
@@ -951,6 +982,7 @@ class PoolStateTestCase(test.TestCase):
                 {'total_capacity_gb': 1024, 'free_capacity_gb': 512,
                  'reserved_percentage': 0, 'timestamp': None,
                  'reserved_snapshot_percentage': 0,
+                 'reserved_share_extend_percentage': 0,
                  'thin_provisioning': False, 'cap1': 'val1', 'cap2': 'val2'},
             'instances':
                 [
@@ -973,6 +1005,7 @@ class PoolStateTestCase(test.TestCase):
                 {'total_capacity_gb': 1024, 'free_capacity_gb': 512,
                  'reserved_percentage': 0, 'timestamp': None,
                  'reserved_snapshot_percentage': 0,
+                 'reserved_share_extend_percentage': 0,
                  'thin_provisioning': [False], 'cap1': 'val1', 'cap2': 'val2'},
             'instances':
                 [
@@ -995,6 +1028,7 @@ class PoolStateTestCase(test.TestCase):
                 {'total_capacity_gb': 1024, 'free_capacity_gb': 512,
                  'reserved_percentage': 0, 'timestamp': None,
                  'reserved_snapshot_percentage': 0,
+                 'reserved_share_extend_percentage': 0,
                  'thin_provisioning': [True, False], 'cap1': 'val1',
                  'cap2': 'val2'},
             'instances':
@@ -1018,6 +1052,7 @@ class PoolStateTestCase(test.TestCase):
                 {'total_capacity_gb': 1024, 'free_capacity_gb': 512,
                  'reserved_percentage': 0, 'timestamp': None,
                  'reserved_snapshot_percentage': 0,
+                 'reserved_share_extend_percentage': 0,
                  'cap1': 'val1', 'cap2': 'val2', 'ipv4_support': True,
                  'ipv6_support': False},
             'instances': []
@@ -1027,6 +1062,7 @@ class PoolStateTestCase(test.TestCase):
                 {'total_capacity_gb': 1024, 'free_capacity_gb': 512,
                  'reserved_percentage': 0, 'timestamp': None,
                  'reserved_snapshot_percentage': 0,
+                 'reserved_share_extend_percentage': 0,
                  'thin_provisioning': True, 'cap1': 'val1', 'cap2': 'val2',
                  'ipv4_support': True, 'ipv6_support': False},
             'instances': []
@@ -1036,6 +1072,7 @@ class PoolStateTestCase(test.TestCase):
                 {'total_capacity_gb': 1024, 'free_capacity_gb': 512,
                  'reserved_percentage': 0, 'timestamp': None,
                  'reserved_snapshot_percentage': 0,
+                 'reserved_share_extend_percentage': 0,
                  'thin_provisioning': [False], 'cap1': 'val1', 'cap2': 'val2',
                  'ipv4_support': True, 'ipv6_support': False},
             'instances': []
@@ -1045,6 +1082,7 @@ class PoolStateTestCase(test.TestCase):
                 {'total_capacity_gb': 1024, 'free_capacity_gb': 512,
                  'reserved_percentage': 0, 'timestamp': None,
                  'reserved_snapshot_percentage': 0,
+                 'reserved_share_extend_percentage': 0,
                  'thin_provisioning': [True, False], 'cap1': 'val1',
                  'cap2': 'val2', 'ipv4_support': True, 'ipv6_support': False},
             'instances': []
@@ -1054,6 +1092,7 @@ class PoolStateTestCase(test.TestCase):
                 {'total_capacity_gb': 1024, 'free_capacity_gb': 512,
                  'allocated_capacity_gb': 256, 'reserved_percentage': 0,
                  'reserved_snapshot_percentage': 0,
+                 'reserved_share_extend_percentage': 0,
                  'timestamp': None, 'cap1': 'val1', 'cap2': 'val2',
                  'ipv4_support': False, 'ipv6_support': True
                  },
@@ -1072,6 +1111,7 @@ class PoolStateTestCase(test.TestCase):
                 {'total_capacity_gb': 1024, 'free_capacity_gb': 512,
                  'allocated_capacity_gb': 256, 'reserved_percentage': 0,
                  'reserved_snapshot_percentage': 0,
+                 'reserved_share_extend_percentage': 0,
                  'timestamp': None, 'cap1': 'val1', 'cap2': 'val2',
                  'ipv4_support': True, 'ipv6_support': True},
             'instances': []
@@ -1081,6 +1121,7 @@ class PoolStateTestCase(test.TestCase):
                 {'total_capacity_gb': 1024, 'free_capacity_gb': 512,
                  'provisioned_capacity_gb': 256, 'reserved_percentage': 0,
                  'reserved_snapshot_percentage': 0,
+                 'reserved_share_extend_percentage': 0,
                  'timestamp': None, 'cap1': 'val1', 'cap2': 'val2',
                  'ipv4_support': False, 'ipv6_support': False
                  },
@@ -1100,6 +1141,7 @@ class PoolStateTestCase(test.TestCase):
                  'allocated_capacity_gb': 256, 'provisioned_capacity_gb': 1,
                  'thin_provisioning': True, 'reserved_percentage': 0,
                  'reserved_snapshot_percentage': 0,
+                 'reserved_share_extend_percentage': 0,
                  'timestamp': None, 'cap1': 'val1', 'cap2': 'val2'},
             'instances':
                 [
@@ -1117,6 +1159,7 @@ class PoolStateTestCase(test.TestCase):
                  'allocated_capacity_gb': 256, 'provisioned_capacity_gb': 1,
                  'thin_provisioning': [False], 'reserved_percentage': 0,
                  'reserved_snapshot_percentage': 0,
+                 'reserved_share_extend_percentage': 0,
                  'timestamp': None, 'cap1': 'val1', 'cap2': 'val2'},
             'instances':
                 [
@@ -1134,6 +1177,7 @@ class PoolStateTestCase(test.TestCase):
                  'allocated_capacity_gb': 256, 'provisioned_capacity_gb': 1,
                  'thin_provisioning': [True, False], 'reserved_percentage': 0,
                  'reserved_snapshot_percentage': 0,
+                 'reserved_share_extend_percentage': 0,
                  'timestamp': None, 'cap1': 'val1', 'cap2': 'val2'},
             'instances':
                 [
@@ -1151,6 +1195,7 @@ class PoolStateTestCase(test.TestCase):
                  'allocated_capacity_gb': 256, 'provisioned_capacity_gb': 256,
                  'thin_provisioning': False, 'reserved_percentage': 0,
                  'reserved_snapshot_percentage': 0,
+                 'reserved_share_extend_percentage': 0,
                  'timestamp': None, 'cap1': 'val1', 'cap2': 'val2'},
             'instances':
                 [
@@ -1168,6 +1213,7 @@ class PoolStateTestCase(test.TestCase):
                  'allocated_capacity_gb': 256, 'provisioned_capacity_gb': 256,
                  'thin_provisioning': [False], 'reserved_percentage': 0,
                  'reserved_snapshot_percentage': 0,
+                 'reserved_share_extend_percentage': 0,
                  'timestamp': None, 'cap1': 'val1', 'cap2': 'val2'},
             'instances':
                 [
@@ -1184,7 +1230,7 @@ class PoolStateTestCase(test.TestCase):
     def test_update_from_share_capability(self, share_capability, instances):
         fake_context = context.RequestContext('user', 'project', is_admin=True)
         self.mock_object(
-            db, 'share_instances_get_all_by_host',
+            db, 'share_instance_get_all_by_host',
             mock.Mock(return_value=instances))
         fake_pool = host_manager.PoolState('host1', None, 'pool0')
         self.assertIsNone(fake_pool.free_capacity_gb)
@@ -1208,19 +1254,19 @@ class PoolStateTestCase(test.TestCase):
             self.assertEqual(thin_provisioned, fake_pool.thin_provisioning)
             if 'provisioned_capacity_gb' not in share_capability or (
                     share_capability['provisioned_capacity_gb'] is None):
-                db.share_instances_get_all_by_host.assert_called_once_with(
+                db.share_instance_get_all_by_host.assert_called_once_with(
                     fake_context, fake_pool.host, with_share_data=True)
                 if len(instances) > 0:
                     self.assertEqual(4, fake_pool.provisioned_capacity_gb)
                 else:
                     self.assertEqual(0, fake_pool.provisioned_capacity_gb)
             else:
-                self.assertFalse(db.share_instances_get_all_by_host.called)
+                self.assertFalse(db.share_instance_get_all_by_host.called)
                 self.assertEqual(share_capability['provisioned_capacity_gb'],
                                  fake_pool.provisioned_capacity_gb)
         else:
             self.assertFalse(fake_pool.thin_provisioning)
-            self.assertFalse(db.share_instances_get_all_by_host.called)
+            self.assertFalse(db.share_instance_get_all_by_host.called)
             if 'provisioned_capacity_gb' not in share_capability or (
                     share_capability['provisioned_capacity_gb'] is None):
                 self.assertIsNone(fake_pool.provisioned_capacity_gb)
