@@ -85,6 +85,10 @@ dummy_opts = [
             "migration_cancel": 1.04,
             "migration_get_progress": 1.05,
             "migration_check_compatibility": 0.05,
+
+            "create_backup": "1.50",
+            "restore_backup": "1.50",
+
         },
     ),
 ]
@@ -177,6 +181,9 @@ class DummyDriver(driver.ShareDriver):
                 ))
 
     def _get_share_name(self, share):
+        mount_point_name = share.get('mount_point_name')
+        if mount_point_name is not None:
+            return mount_point_name
         return "share_%(s_id)s_%(si_id)s" % {
             "s_id": share["share_id"].replace("-", "_"),
             "si_id": share["id"].replace("-", "_")}
@@ -512,6 +519,7 @@ class DummyDriver(driver.ShareDriver):
                 "consistent_snapshot_support": "pool",
             },
             'share_server_multiple_subnet_support': True,
+            'mount_point_name_support': True,
         }
         if self.configuration.replication_domain:
             data["replication_type"] = "readable"
@@ -1010,3 +1018,39 @@ class DummyDriver(driver.ShareDriver):
                     new_server["backend_details"]["subnet_allocations"])
             },
         }
+
+    @slow_me_down
+    def create_backup(self, context, share_instance, backup,
+                      share_server=None):
+        LOG.debug("Created backup %(backup)s of share %(share)s "
+                  "using dummy driver.",
+                  {'backup': backup['id'],
+                   'share': share_instance['share_id']})
+
+    def create_backup_continue(self, context, share_instance, backup,
+                               share_server=None):
+        LOG.debug("Continue backup %(backup)s of share %(share)s "
+                  "using dummy driver.",
+                  {'backup': backup['id'],
+                   'share': share_instance['share_id']})
+        return {'total_progress': '100'}
+
+    def delete_backup(self, context, backup, share_instance,
+                      share_server=None):
+        LOG.debug("Deleted backup '%s' using dummy driver.", backup['id'])
+
+    @slow_me_down
+    def restore_backup(self, context, backup, share_instance,
+                       share_server=None):
+        LOG.debug("Restored backup %(backup)s into share %(share)s "
+                  "using dummy driver.",
+                  {'backup': backup['id'],
+                   'share': share_instance['share_id']})
+
+    def restore_backup_continue(self, context, backup, share_instance,
+                                share_server=None):
+        LOG.debug("Continue restore of backup %(backup)s into share "
+                  "%(share)s using dummy driver.",
+                  {'backup': backup['id'],
+                   'share': share_instance['share_id']})
+        return {'total_progress': '100'}
