@@ -23,8 +23,8 @@ import paramiko
 
 from manila import exception
 from manila.share.drivers.hitachi.hnas import ssh
+from manila import ssh_utils
 from manila import test
-from manila import utils as mutils
 
 
 CONF = cfg.CONF
@@ -286,7 +286,7 @@ HNAS_RESULT_tree_job_status_fail = """JOB ID : d933100a-b5f6-11d0-91d9-836896aad
         Source files missing           : 0
         Source files skipped           : 801
         Skipping details               : 104 symlinks, 452 hard links,
-47 block special devices, 25 character devices"""
+47 block special devices, 25 character devices"""  # noqa
 
 HNAS_RESULT_job_completed = """JOB ID : ab4211b8-aac8-11ce-91af-39e0822ea368
       Job request
@@ -1506,7 +1506,7 @@ class HNASSSHTestCase(test.TestCase):
                          mock.Mock(side_effect=[
                              putils.ProcessExecutionError(stderr=msg),
                              putils.ProcessExecutionError(stderr='Invalid!')]))
-        self.mock_object(mutils.SSHPool, "item",
+        self.mock_object(ssh_utils.SSHPool, "item",
                          mock.Mock(return_value=paramiko.SSHClient()))
         self.mock_object(paramiko.SSHClient, "set_missing_host_key_policy")
 
