@@ -728,6 +728,7 @@ class HPE3ParDriverTestCase(test.TestCase):
             'max_over_subscription_ratio': None,
             'reserved_percentage': 0,
             'reserved_snapshot_percentage': 0,
+            'reserved_share_extend_percentage': 0,
             'provisioned_capacity_gb': 0,
             'share_backend_name': 'HPE_3PAR',
             'snapshot_support': True,
@@ -745,6 +746,7 @@ class HPE3ParDriverTestCase(test.TestCase):
             'replication_domain': None,
             'filter_function': None,
             'goodness_function': None,
+            'mount_point_name_support': False,
             'ipv4_support': True,
             'ipv6_support': False,
             'max_share_server_size': -1,
@@ -792,6 +794,7 @@ class HPE3ParDriverTestCase(test.TestCase):
             'hp3par_flash_cache': False,
             'reserved_percentage': 0,
             'reserved_snapshot_percentage': 0,
+            'reserved_share_extend_percentage': 0,
             'provisioned_capacity_gb': expected_capacity
         }
 
@@ -806,6 +809,7 @@ class HPE3ParDriverTestCase(test.TestCase):
             'provisioned_capacity_gb': 0,
             'reserved_percentage': 0,
             'reserved_snapshot_percentage': 0,
+            'reserved_share_extend_percentage': 0,
             'max_over_subscription_ratio': None,
             'max_share_server_size': -1,
             'max_shares_per_share_server': -1,
@@ -821,6 +825,7 @@ class HPE3ParDriverTestCase(test.TestCase):
                 'hp3par_flash_cache': False,
                 'reserved_percentage': 0,
                 'reserved_snapshot_percentage': 0,
+                'reserved_share_extend_percentage': 0,
                 'provisioned_capacity_gb': expected_capacity}],
             'snapshot_support': True,
             'create_share_from_snapshot_support': True,
@@ -835,6 +840,7 @@ class HPE3ParDriverTestCase(test.TestCase):
             'replication_domain': None,
             'filter_function': None,
             'goodness_function': None,
+            'mount_point_name_support': False,
             'ipv4_support': True,
             'ipv6_support': False,
         }
@@ -867,6 +873,7 @@ class HPE3ParDriverTestCase(test.TestCase):
             'provisioned_capacity_gb': 0,
             'reserved_percentage': 0,
             'reserved_snapshot_percentage': 0,
+            'reserved_share_extend_percentage': 0,
             'share_backend_name': 'HPE_3PAR',
             'storage_protocol': 'NFS_CIFS',
             'thin_provisioning': True,
@@ -885,6 +892,7 @@ class HPE3ParDriverTestCase(test.TestCase):
             'replication_domain': None,
             'filter_function': None,
             'goodness_function': None,
+            'mount_point_name_support': False,
             'ipv4_support': True,
             'ipv6_support': False,
         }
