@@ -61,6 +61,8 @@ class FakeConfig(object):
             "reserved_share_percentage", 0)
         self.reserved_share_from_snapshot_percentage = kwargs.get(
             "reserved_share_from_snapshot_percentage", 0)
+        self.reserved_share_extend_percentage = kwargs.get(
+            "reserved_share_extend_percentage", 0)
         self.max_over_subscription_ratio = kwargs.get(
             "max_over_subscription_ratio", 20.0)
         self.filter_function = kwargs.get("filter_function", None)
@@ -884,6 +886,7 @@ class AS13000ShareDriverTestCase(test.TestCase):
         pool['pool_name'] = 'fakepath'
         pool['reserved_percentage'] = 0
         pool['reserved_snapshot_percentage'] = 0
+        pool['reserved_share_extend_percentage'] = 0
         pool['max_over_subscription_ratio'] = 20.0
         pool['dedupe'] = False
         pool['compression'] = False
