@@ -40,6 +40,7 @@ SHARE_NAME = 'share_7cf7c200_d3af_4e05_b87e_9167c95dfcad'
 SHARE_NAME2 = 'share_d24e7257_124e_4fb6_b05b_d384f660bc85'
 SHARE_INSTANCE_NAME = 'share_d24e7257_124e_4fb6_b05b_d384f660bc85'
 FLEXVOL_NAME = 'fake_volume'
+FLEXVOL_NAME_1 = 'fake_volume_1'
 JUNCTION_PATH = '/%s' % FLEXVOL_NAME
 EXPORT_LOCATION = '%s:%s' % (HOST_NAME, JUNCTION_PATH)
 SNAPSHOT_NAME = 'fake_snapshot'
@@ -112,6 +113,8 @@ FPOLICY_EXT_TO_INCLUDE = 'avi'
 FPOLICY_EXT_TO_INCLUDE_LIST = ['avi']
 FPOLICY_EXT_TO_EXCLUDE = 'jpg,mp3'
 FPOLICY_EXT_TO_EXCLUDE_LIST = ['jpg', 'mp3']
+BACKUP_TYPE = "fake_backup_type"
+MOUNT_POINT_NAME = 'fake_mp'
 
 JOB_ID = '123'
 JOB_STATE = 'success'
@@ -133,6 +136,7 @@ SHARE = {
     'host': MANILA_HOST_NAME,
     'project_id': TENANT_ID,
     'name': SHARE_NAME,
+    'mount_point_name': MOUNT_POINT_NAME,
     'size': SHARE_SIZE,
     'share_proto': 'fake',
     'share_type_id': 'fake_share_type_id',
@@ -193,6 +197,7 @@ SHARE_INSTANCE = {
     'share_id': SHARE_ID,
     'host': MANILA_HOST_NAME,
     'project_id': TENANT_ID,
+    'mount_point_name': MOUNT_POINT_NAME,
     'name': SHARE_INSTANCE_NAME,
     'size': SHARE_SIZE,
     'share_proto': 'fake',
@@ -571,6 +576,7 @@ NETWORK_INFO_NETMASK = '255.255.255.0'
 SHARE_SERVER = {
     'id': 'fake_id',
     'share_network_id': 'c5b3a865-56d0-4d88-abe5-879965e099c9',
+    'identifier': 'fake_id',
     'backend_details': {
         'vserver_name': VSERVER1
     },
@@ -1034,6 +1040,7 @@ POOLS = [
         'utilization': 30.0,
         'filter_function': 'filter',
         'goodness_function': 'goodness',
+        'mount_point_name_support': True,
         'snapshot_support': True,
         'create_share_from_snapshot_support': True,
         'revert_to_snapshot_support': True,
@@ -1079,6 +1086,7 @@ POOLS_VSERVER_CREDS = [
         'pool_name': AGGREGATES[0],
         'filter_function': None,
         'goodness_function': None,
+        'mount_point_name_support': True,
         'netapp_cluster_name': '',
         'netapp_aggregate': AGGREGATES[0],
         'total_capacity_gb': 'unknown',
@@ -1131,11 +1139,13 @@ SSC_AGGREGATES = [
         'name': AGGREGATES[0],
         'raid-type': 'raid4',
         'is-hybrid': False,
+        'is-home': False,
     },
     {
         'name': AGGREGATES[1],
         'raid-type': 'raid_dp',
         'is-hybrid': True,
+        'is-home': True,
     },
 ]
 
@@ -1866,6 +1876,24 @@ NEW_NETWORK_ALLOCATIONS = {
     'network_allocations': USER_NETWORK_ALLOCATIONS
 }
 
+SHARE_BACKUP = {
+    'id': '242ff47e-518d-4b07-b3c3-0a51e6744149',
+    'share_id': 'd0a424c3-fee9-4781-9d4a-2c48a63386aa',
+    'size': SHARE_SIZE,
+    'host': MANILA_HOST_NAME,
+    'display_name': 'fake_backup',
+    'backup_options': {'backend': BACKEND_NAME, 'backup_type': BACKUP_TYPE},
+    }
+
+SNAP_MIRROR_INFO = {'source-vserver': VSERVER1,
+                    'source-volume': FLEXVOL_NAME,
+                    'destination-vserver': VSERVER2,
+                    'destination-volume': FLEXVOL_NAME_1,
+                    'relationship-status': "idle",
+                    'last-transfer-type': "update",
+                    }
+
+
 SERVER_MODEL_UPDATE = {
     'server_details': {
         'ports': '{"%s": "%s", "%s": "%s"}' % (
