@@ -44,14 +44,19 @@ class NetAppClusteredNFSHelperTestCase(test.TestCase):
     def test__escaped_address(self, raw, escaped):
         self.assertEqual(escaped, self.helper._escaped_address(raw))
 
-    def test_create_share(self):
+    @ddt.data(True, False)
+    def test_create_share(self, is_flexgroup):
 
         mock_ensure_export_policy = self.mock_object(self.helper,
                                                      '_ensure_export_policy')
         self.mock_client.get_volume_junction_path.return_value = (
             fake.NFS_SHARE_PATH)
+        self.mock_client.get_volume.return_value = {
+            'junction-path': fake.NFS_SHARE_PATH,
+        }
 
-        result = self.helper.create_share(fake.NFS_SHARE, fake.SHARE_NAME)
+        result = self.helper.create_share(fake.NFS_SHARE, fake.SHARE_NAME,
+                                          is_flexgroup=is_flexgroup)
 
         export_addresses = [fake.SHARE_ADDRESS_1, fake.SHARE_ADDRESS_2]
         export_paths = [result(address) for address in export_addresses]
@@ -63,6 +68,10 @@ class NetAppClusteredNFSHelperTestCase(test.TestCase):
         (self.mock_client.clear_nfs_export_policy_for_volume.
             assert_called_once_with(fake.SHARE_NAME))
         self.assertTrue(mock_ensure_export_policy.called)
+        if is_flexgroup:
+            self.assertTrue(self.mock_client.get_volume.called)
+        else:
+            self.assertTrue(self.mock_client.get_volume_junction_path.called)
 
     def test_delete_share(self):
 
@@ -163,6 +172,10 @@ class NetAppClusteredNFSHelperTestCase(test.TestCase):
 
     def test_get_export_location(self):
 
+        export = fake.NFS_SHARE['export_location']
+        self.mock_object(self.helper, '_get_share_export_location',
+                         mock.Mock(return_value=export))
+
         host_ip, export_path = self.helper._get_export_location(
             fake.NFS_SHARE)
         self.assertEqual(fake.SHARE_ADDRESS_1, host_ip)
@@ -173,11 +186,15 @@ class NetAppClusteredNFSHelperTestCase(test.TestCase):
 
         fake_share = fake.NFS_SHARE.copy()
         fake_share['export_location'] = export
+        self.mock_object(self.helper, '_get_share_export_location',
+                         mock.Mock(return_value=export))
 
         host_ip, export_path = self.helper._get_export_location(fake_share)
 
         self.assertEqual('', host_ip)
         self.assertEqual('', export_path)
+        self.helper._get_share_export_location.assert_called_once_with(
+            fake_share)
 
     def test_get_temp_export_policy_name(self):
 
@@ -233,3 +250,11 @@ class NetAppClusteredNFSHelperTestCase(test.TestCase):
         result = self.helper._get_auth_methods()
 
         self.assertEqual(security_flavors, result)
+
+    def test_cleanup_demoted_replica(self):
+
+        self.mock_object(self.helper, 'delete_share')
+        self.helper.cleanup_demoted_replica(fake.NFS_SHARE, fake.SHARE_NAME)
+
+        self.helper.delete_share.assert_called_once_with(fake.NFS_SHARE,
+                                                         fake.SHARE_NAME)
