@@ -12,8 +12,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
-import six
+from unittest import mock
 
 from manila import exception
 from manila.share.drivers.netapp import common as na_common
@@ -112,7 +111,7 @@ class NetAppDriverFactoryTestCase(test.TestCase):
 
         registry = na_common.NETAPP_UNIFIED_DRIVER_REGISTRY
 
-        for family in six.iterkeys(registry):
+        for family in iter(registry.keys()):
             for mode, full_class_name in registry[family].items():
 
                 config = na_fakes.create_configuration()
