@@ -432,11 +432,13 @@ class ACCESSShareDriverTestCase(test.TestCase):
             'free_capacity_gb': 9,
             'reserved_percentage': 0,
             'reserved_snapshot_percentage': 0,
+            'reserved_share_extend_percentage': 0,
             'QoS_support': False,
             'create_share_from_snapshot_support': True,
             'driver_handles_share_servers': False,
             'filter_function': 'Disable',
             'goodness_function': 'Disable',
+            'mount_point_name_support': False,
             'ipv4_support': True,
             'ipv6_support': False,
             'mount_snapshot_support': False,
