@@ -141,8 +141,10 @@ class ShareDriverTestCase(test.TestCase):
             'free_capacity_gb', 'total_capacity_gb',
             'driver_handles_share_servers',
             'reserved_percentage', 'reserved_snapshot_percentage',
+            'reserved_share_extend_percentage',
             'vendor_name', 'storage_protocol',
             'snapshot_support', 'mount_snapshot_support',
+            'mount_point_name_support',
         ]
         share_driver = driver.ShareDriver(True, configuration=conf)
         fake_stats = {'fake_key': 'fake_value'}
