@@ -21,8 +21,11 @@
 Unit Tests for remote procedure calls using queue
 """
 
+from datetime import datetime
+from datetime import timedelta
+from unittest import mock
+
 import ddt
-import mock
 from oslo_config import cfg
 from oslo_service import wsgi
 
@@ -119,13 +122,32 @@ service_create = {
     'host': host,
     'binary': binary,
     'topic': topic,
+    'state': 'up',
     'report_count': 0,
     'availability_zone': 'nova',
 }
+service_create_other_az = {
+    'host': host,
+    'binary': binary,
+    'topic': topic,
+    'state': 'up',
+    'report_count': 0,
+    'availability_zone': 'other-zone',
+}
 service_ref = {
     'host': host,
     'binary': binary,
     'topic': topic,
+    'state': 'up',
+    'report_count': 0,
+    'availability_zone': {'name': 'nova'},
+    'id': 1,
+}
+service_ref_stopped = {
+    'host': host,
+    'binary': binary,
+    'topic': topic,
+    'state': 'stopped',
     'report_count': 0,
     'availability_zone': {'name': 'nova'},
     'id': 1,
@@ -184,6 +206,8 @@ class ServiceTestCase(test.TestCase):
     @mock.patch.object(service.db, 'service_update',
                        mock.Mock(return_value=service_ref.
                                  update({'report_count': 1})))
+    @mock.patch.object(utils, 'service_is_up',
+                       mock.Mock(return_value=True))
     def test_report_state_newly_connected(self):
         serv = service.Service(host, binary, topic, CONF.fake_manager)
         serv.start()
@@ -199,6 +223,94 @@ class ServiceTestCase(test.TestCase):
         service.db.service_update.assert_called_once_with(
             mock.ANY, service_ref['id'], mock.ANY)
 
+    @mock.patch.object(service.db, 'service_get_by_args',
+                       mock.Mock(side_effect=fake_service_get_by_args))
+    @mock.patch.object(service.db, 'service_create',
+                       mock.Mock(return_value=service_ref))
+    @mock.patch.object(service.db, 'service_get',
+                       mock.Mock(return_value=service_ref))
+    @mock.patch.object(service.db, 'service_update',
+                       mock.Mock(return_value=service_ref.
+                                 update({'report_count': 1})))
+    @mock.patch.object(utils, 'service_is_up',
+                       mock.Mock(return_value=True))
+    def test_report_state_newly_connected_different_az(self):
+        serv = service.Service(host, binary, topic, CONF.fake_manager)
+        serv.availability_zone = 'other-zone'
+        serv.start()
+        serv.model_disconnected = True
+        serv.report_state()
+        self.assertFalse(serv.model_disconnected)
+        service.db.service_get_by_args.assert_called_once_with(
+            mock.ANY, host, binary)
+        service.db.service_create.assert_called_once_with(
+            mock.ANY, service_create_other_az)
+        service.db.service_get.assert_called_once_with(
+            mock.ANY, service_ref['id'])
+        service.db.service_update.assert_called_once_with(
+            mock.ANY, service_ref['id'], mock.ANY)
+
+    @mock.patch.object(service.db, 'service_get_by_args',
+                       mock.Mock(side_effect=fake_service_get_by_args))
+    @mock.patch.object(service.db, 'service_create',
+                       mock.Mock(return_value=service_ref))
+    @mock.patch.object(service.db, 'service_get',
+                       mock.Mock(side_effect=[exception.NotFound,
+                                              service_ref]))
+    @mock.patch.object(service.db, 'service_update',
+                       mock.Mock(return_value=service_ref.
+                                 update({'report_count': 1})))
+    @mock.patch.object(utils, 'service_is_up',
+                       mock.Mock(return_value=True))
+    def test_report_state_newly_connected_not_found(self):
+        serv = service.Service(host, binary, topic, CONF.fake_manager)
+        serv.start()
+        serv.model_disconnected = True
+        serv.report_state()
+        self.assertFalse(serv.model_disconnected)
+        service.db.service_get_by_args.assert_called_once_with(
+            mock.ANY, host, binary)
+        service.db.service_create.assert_has_calls([
+            mock.call(mock.ANY, service_create),
+            mock.call(mock.ANY, service_create)])
+        service.db.service_get.assert_has_calls([
+            mock.call(mock.ANY, service_ref['id']),
+            mock.call(mock.ANY, service_ref['id'])])
+        service.db.service_update.assert_called_once_with(
+            mock.ANY, service_ref['id'], mock.ANY)
+
+    def test_report_state_service_not_ready(self):
+        with mock.patch.object(service, 'db') as mock_db:
+            mock_db.service_get.return_value = service_ref
+            serv = service.Service(host, binary, topic, CONF.fake_manager)
+            serv.manager.is_service_ready = mock.Mock(return_value=False)
+            serv.start()
+            serv.report_state()
+
+            serv.manager.is_service_ready.assert_called_once()
+
+    @ddt.data(True, False)
+    def test_cleanup_services(self, cleanup_interval_done):
+        with mock.patch.object(service, 'db') as mock_db:
+            mock_db.service_get_all.return_value = [service_ref]
+            serv = service.Service(host, binary, topic, CONF.fake_manager)
+            serv.start()
+            serv.cleanup_services()
+            mock_db.service_destroy.assert_not_called()
+
+            if cleanup_interval_done:
+                service_ref_stopped['updated_at'] = (
+                    datetime.utcnow() - timedelta(minutes=10))
+            else:
+                service_ref_stopped['updated_at'] = datetime.utcnow()
+            mock_db.service_get_all_by_topic.return_value = [
+                service_ref_stopped]
+            serv.stop()
+            serv.cleanup_services()
+            if cleanup_interval_done:
+                mock_db.service_destroy.assert_called_once_with(
+                    mock.ANY, service_ref_stopped['id'])
+
 
 class TestWSGIService(test.TestCase):
 
